/*! For license information please see 7107eafb.js.LICENSE.txt */
"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[3835],{65660:(e,t,n)=>{n(94604);const s=n(50856).d`
<custom-style>
  <style is="custom-style">
    [hidden] {
      display: none !important;
    }
  </style>
</custom-style>
<custom-style>
  <style is="custom-style">
    html {

      --layout: {
        display: -ms-flexbox;
        display: -webkit-flex;
        display: flex;
      };

      --layout-inline: {
        display: -ms-inline-flexbox;
        display: -webkit-inline-flex;
        display: inline-flex;
      };

      --layout-horizontal: {
        @apply --layout;

        -ms-flex-direction: row;
        -webkit-flex-direction: row;
        flex-direction: row;
      };

      --layout-horizontal-reverse: {
        @apply --layout;

        -ms-flex-direction: row-reverse;
        -webkit-flex-direction: row-reverse;
        flex-direction: row-reverse;
      };

      --layout-vertical: {
        @apply --layout;

        -ms-flex-direction: column;
        -webkit-flex-direction: column;
        flex-direction: column;
      };

      --layout-vertical-reverse: {
        @apply --layout;

        -ms-flex-direction: column-reverse;
        -webkit-flex-direction: column-reverse;
        flex-direction: column-reverse;
      };

      --layout-wrap: {
        -ms-flex-wrap: wrap;
        -webkit-flex-wrap: wrap;
        flex-wrap: wrap;
      };

      --layout-wrap-reverse: {
        -ms-flex-wrap: wrap-reverse;
        -webkit-flex-wrap: wrap-reverse;
        flex-wrap: wrap-reverse;
      };

      --layout-flex-auto: {
        -ms-flex: 1 1 auto;
        -webkit-flex: 1 1 auto;
        flex: 1 1 auto;
      };

      --layout-flex-none: {
        -ms-flex: none;
        -webkit-flex: none;
        flex: none;
      };

      --layout-flex: {
        -ms-flex: 1 1 0.000000001px;
        -webkit-flex: 1;
        flex: 1;
        -webkit-flex-basis: 0.000000001px;
        flex-basis: 0.000000001px;
      };

      --layout-flex-2: {
        -ms-flex: 2;
        -webkit-flex: 2;
        flex: 2;
      };

      --layout-flex-3: {
        -ms-flex: 3;
        -webkit-flex: 3;
        flex: 3;
      };

      --layout-flex-4: {
        -ms-flex: 4;
        -webkit-flex: 4;
        flex: 4;
      };

      --layout-flex-5: {
        -ms-flex: 5;
        -webkit-flex: 5;
        flex: 5;
      };

      --layout-flex-6: {
        -ms-flex: 6;
        -webkit-flex: 6;
        flex: 6;
      };

      --layout-flex-7: {
        -ms-flex: 7;
        -webkit-flex: 7;
        flex: 7;
      };

      --layout-flex-8: {
        -ms-flex: 8;
        -webkit-flex: 8;
        flex: 8;
      };

      --layout-flex-9: {
        -ms-flex: 9;
        -webkit-flex: 9;
        flex: 9;
      };

      --layout-flex-10: {
        -ms-flex: 10;
        -webkit-flex: 10;
        flex: 10;
      };

      --layout-flex-11: {
        -ms-flex: 11;
        -webkit-flex: 11;
        flex: 11;
      };

      --layout-flex-12: {
        -ms-flex: 12;
        -webkit-flex: 12;
        flex: 12;
      };

      /* alignment in cross axis */

      --layout-start: {
        -ms-flex-align: start;
        -webkit-align-items: flex-start;
        align-items: flex-start;
      };

      --layout-center: {
        -ms-flex-align: center;
        -webkit-align-items: center;
        align-items: center;
      };

      --layout-end: {
        -ms-flex-align: end;
        -webkit-align-items: flex-end;
        align-items: flex-end;
      };

      --layout-baseline: {
        -ms-flex-align: baseline;
        -webkit-align-items: baseline;
        align-items: baseline;
      };

      /* alignment in main axis */

      --layout-start-justified: {
        -ms-flex-pack: start;
        -webkit-justify-content: flex-start;
        justify-content: flex-start;
      };

      --layout-center-justified: {
        -ms-flex-pack: center;
        -webkit-justify-content: center;
        justify-content: center;
      };

      --layout-end-justified: {
        -ms-flex-pack: end;
        -webkit-justify-content: flex-end;
        justify-content: flex-end;
      };

      --layout-around-justified: {
        -ms-flex-pack: distribute;
        -webkit-justify-content: space-around;
        justify-content: space-around;
      };

      --layout-justified: {
        -ms-flex-pack: justify;
        -webkit-justify-content: space-between;
        justify-content: space-between;
      };

      --layout-center-center: {
        @apply --layout-center;
        @apply --layout-center-justified;
      };

      /* self alignment */

      --layout-self-start: {
        -ms-align-self: flex-start;
        -webkit-align-self: flex-start;
        align-self: flex-start;
      };

      --layout-self-center: {
        -ms-align-self: center;
        -webkit-align-self: center;
        align-self: center;
      };

      --layout-self-end: {
        -ms-align-self: flex-end;
        -webkit-align-self: flex-end;
        align-self: flex-end;
      };

      --layout-self-stretch: {
        -ms-align-self: stretch;
        -webkit-align-self: stretch;
        align-self: stretch;
      };

      --layout-self-baseline: {
        -ms-align-self: baseline;
        -webkit-align-self: baseline;
        align-self: baseline;
      };

      /* multi-line alignment in main axis */

      --layout-start-aligned: {
        -ms-flex-line-pack: start;  /* IE10 */
        -ms-align-content: flex-start;
        -webkit-align-content: flex-start;
        align-content: flex-start;
      };

      --layout-end-aligned: {
        -ms-flex-line-pack: end;  /* IE10 */
        -ms-align-content: flex-end;
        -webkit-align-content: flex-end;
        align-content: flex-end;
      };

      --layout-center-aligned: {
        -ms-flex-line-pack: center;  /* IE10 */
        -ms-align-content: center;
        -webkit-align-content: center;
        align-content: center;
      };

      --layout-between-aligned: {
        -ms-flex-line-pack: justify;  /* IE10 */
        -ms-align-content: space-between;
        -webkit-align-content: space-between;
        align-content: space-between;
      };

      --layout-around-aligned: {
        -ms-flex-line-pack: distribute;  /* IE10 */
        -ms-align-content: space-around;
        -webkit-align-content: space-around;
        align-content: space-around;
      };

      /*******************************
                Other Layout
      *******************************/

      --layout-block: {
        display: block;
      };

      --layout-invisible: {
        visibility: hidden !important;
      };

      --layout-relative: {
        position: relative;
      };

      --layout-fit: {
        position: absolute;
        top: 0;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-scroll: {
        -webkit-overflow-scrolling: touch;
        overflow: auto;
      };

      --layout-fullbleed: {
        margin: 0;
        height: 100vh;
      };

      /* fixed position */

      --layout-fixed-top: {
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
      };

      --layout-fixed-right: {
        position: fixed;
        top: 0;
        right: 0;
        bottom: 0;
      };

      --layout-fixed-bottom: {
        position: fixed;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-fixed-left: {
        position: fixed;
        top: 0;
        bottom: 0;
        left: 0;
      };

    }
  </style>
</custom-style>`;s.setAttribute("style","display: none;"),document.head.appendChild(s.content);var r=document.createElement("style");r.textContent="[hidden] { display: none !important; }",document.head.appendChild(r)},43835:(e,t,n)=>{n(65660),n(54242),n(70019)},54242:(e,t,n)=>{n(94604);const s=n(50856).d`
<custom-style>
  <style is="custom-style">
    html {

      --shadow-transition: {
        transition: box-shadow 0.28s cubic-bezier(0.4, 0, 0.2, 1);
      };

      --shadow-none: {
        box-shadow: none;
      };

      /* from http://codepen.io/shyndman/pen/c5394ddf2e8b2a5c9185904b57421cdb */

      --shadow-elevation-2dp: {
        box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14),
                    0 1px 5px 0 rgba(0, 0, 0, 0.12),
                    0 3px 1px -2px rgba(0, 0, 0, 0.2);
      };

      --shadow-elevation-3dp: {
        box-shadow: 0 3px 4px 0 rgba(0, 0, 0, 0.14),
                    0 1px 8px 0 rgba(0, 0, 0, 0.12),
                    0 3px 3px -2px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-4dp: {
        box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14),
                    0 1px 10px 0 rgba(0, 0, 0, 0.12),
                    0 2px 4px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-6dp: {
        box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14),
                    0 1px 18px 0 rgba(0, 0, 0, 0.12),
                    0 3px 5px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-8dp: {
        box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14),
                    0 3px 14px 2px rgba(0, 0, 0, 0.12),
                    0 5px 5px -3px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-12dp: {
        box-shadow: 0 12px 16px 1px rgba(0, 0, 0, 0.14),
                    0 4px 22px 3px rgba(0, 0, 0, 0.12),
                    0 6px 7px -4px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-16dp: {
        box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14),
                    0  6px 30px 5px rgba(0, 0, 0, 0.12),
                    0  8px 10px -5px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-24dp: {
        box-shadow: 0 24px 38px 3px rgba(0, 0, 0, 0.14),
                    0 9px 46px 8px rgba(0, 0, 0, 0.12),
                    0 11px 15px -7px rgba(0, 0, 0, 0.4);
      };
    }
  </style>
</custom-style>`;s.setAttribute("style","display: none;"),document.head.appendChild(s.content)},70019:(e,t,n)=>{n(94604);const s=n(50856).d`<custom-style>
  <style is="custom-style">
    html {

      /* Shared Styles */
      --paper-font-common-base: {
        font-family: 'Roboto', 'Noto', sans-serif;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-code: {
        font-family: 'Roboto Mono', 'Consolas', 'Menlo', monospace;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-expensive-kerning: {
        text-rendering: optimizeLegibility;
      };

      --paper-font-common-nowrap: {
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      };

      /* Material Font Styles */

      --paper-font-display4: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 112px;
        font-weight: 300;
        letter-spacing: -.044em;
        line-height: 120px;
      };

      --paper-font-display3: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 56px;
        font-weight: 400;
        letter-spacing: -.026em;
        line-height: 60px;
      };

      --paper-font-display2: {
        @apply --paper-font-common-base;

        font-size: 45px;
        font-weight: 400;
        letter-spacing: -.018em;
        line-height: 48px;
      };

      --paper-font-display1: {
        @apply --paper-font-common-base;

        font-size: 34px;
        font-weight: 400;
        letter-spacing: -.01em;
        line-height: 40px;
      };

      --paper-font-headline: {
        @apply --paper-font-common-base;

        font-size: 24px;
        font-weight: 400;
        letter-spacing: -.012em;
        line-height: 32px;
      };

      --paper-font-title: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 20px;
        font-weight: 500;
        line-height: 28px;
      };

      --paper-font-subhead: {
        @apply --paper-font-common-base;

        font-size: 16px;
        font-weight: 400;
        line-height: 24px;
      };

      --paper-font-body2: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-body1: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 400;
        line-height: 20px;
      };

      --paper-font-caption: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 12px;
        font-weight: 400;
        letter-spacing: 0.011em;
        line-height: 20px;
      };

      --paper-font-menu: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 13px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-button: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 14px;
        font-weight: 500;
        letter-spacing: 0.018em;
        line-height: 24px;
        text-transform: uppercase;
      };

      --paper-font-code2: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 700;
        line-height: 20px;
      };

      --paper-font-code1: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 500;
        line-height: 20px;
      };

    }

  </style>
</custom-style>`;s.setAttribute("style","display: none;"),document.head.appendChild(s.content)},5618:(e,t,n)=>{var s=n(34816),r=n(10868),i=n(26539);const o=new s.ZP;window.ShadyCSS||(window.ShadyCSS={prepareTemplate(e,t,n){},prepareTemplateDom(e,t){},prepareTemplateStyles(e,t,n){},styleSubtree(e,t){o.processStyles(),(0,r.wW)(e,t)},styleElement(e){o.processStyles()},styleDocument(e){o.processStyles(),(0,r.wW)(document.body,e)},getComputedStyleValue:(e,t)=>(0,r.B7)(e,t),flushCustomStyles(){},nativeCss:i.rd,nativeShadow:i.WA,cssBuild:i.Cp,disableRuntime:i.jF}),window.ShadyCSS.CustomStyleInterface=o;var a=n(15392);const l="include",d=window.ShadyCSS.CustomStyleInterface;class c extends HTMLElement{constructor(){super(),this._style=null,d.addCustomStyle(this)}getStyle(){if(this._style)return this._style;const e=this.querySelector("style");if(!e)return null;this._style=e;const t=e.getAttribute(l);return t&&(e.removeAttribute(l),e.textContent=(0,a.jv)(t)+e.textContent),this.ownerDocument!==window.document&&window.document.head.appendChild(this),this._style}}window.customElements.define("custom-style",c)},21384:(e,t,n)=>{n.d(t,{t:()=>d});n(56646);var s=n(42687),r=n(74460);let i={},o={};function a(e,t){i[e]=o[e.toLowerCase()]=t}function l(e){return i[e]||o[e.toLowerCase()]}class d extends HTMLElement{static get observedAttributes(){return["id"]}static import(e,t){if(e){let n=l(e);return n&&t?n.querySelector(t):n}return null}attributeChangedCallback(e,t,n,s){t!==n&&this.register()}get assetpath(){if(!this.__assetpath){const e=window.HTMLImports&&HTMLImports.importForElement?HTMLImports.importForElement(this)||document:this.ownerDocument,t=(0,s.Kk)(this.getAttribute("assetpath")||"",e.baseURI);this.__assetpath=(0,s.iY)(t)}return this.__assetpath}register(e){if(e=e||this.id){if(r.XN&&void 0!==l(e))throw a(e,null),new Error(`strictTemplatePolicy: dom-module ${e} re-registered`);this.id=e,a(e,this),(t=this).querySelector("style")&&console.warn("dom-module %s has style outside template",t.id)}var t}}d.prototype.modules=i,customElements.define("dom-module",d)},42173:(e,t,n)=>{var s=n(28426),r=n(52521),i=n(78956),o=n(93252),a=n(18691),l=n(4059),d=n(21683),c=n(62276),h=n(6226),p=n(74460);const u=(0,a.w)(s.H3);class _ extends u{static get is(){return"dom-repeat"}static get template(){return null}static get properties(){return{items:{type:Array},as:{type:String,value:"item"},indexAs:{type:String,value:"index"},itemsIndexAs:{type:String,value:"itemsIndex"},sort:{type:Function,observer:"__sortChanged"},filter:{type:Function,observer:"__filterChanged"},observe:{type:String,observer:"__observeChanged"},delay:Number,renderedItemCount:{type:Number,notify:!p.dJ,readOnly:!0},initialCount:{type:Number},targetFramerate:{type:Number,value:20},_targetFrameTime:{type:Number,computed:"__computeFrameTime(targetFramerate)"},notifyDomChange:{type:Boolean},reuseChunkedInstances:{type:Boolean}}}static get observers(){return["__itemsChanged(items.*)"]}constructor(){super(),this.__instances=[],this.__renderDebouncer=null,this.__itemsIdxToInstIdx={},this.__chunkCount=null,this.__renderStartTime=null,this.__itemsArrayChanged=!1,this.__shouldMeasureChunk=!1,this.__shouldContinueChunking=!1,this.__chunkingId=0,this.__sortFn=null,this.__filterFn=null,this.__observePaths=null,this.__ctor=null,this.__isDetached=!0,this.template=null,this._templateInfo}disconnectedCallback(){super.disconnectedCallback(),this.__isDetached=!0;for(let e=0;e<this.__instances.length;e++)this.__detachInstance(e)}connectedCallback(){if(super.connectedCallback(),(0,h.N)()||(this.style.display="none"),this.__isDetached){this.__isDetached=!1;let e=(0,c.r)((0,c.r)(this).parentNode);for(let t=0;t<this.__instances.length;t++)this.__attachInstance(t,e)}}__ensureTemplatized(){if(!this.__ctor){const e=this;let t=this.template=e._templateInfo?e:this.querySelector("template");if(!t){let e=new MutationObserver((()=>{if(!this.querySelector("template"))throw new Error("dom-repeat requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}let n={};n[this.as]=!0,n[this.indexAs]=!0,n[this.itemsIndexAs]=!0,this.__ctor=(0,r.Uv)(t,this,{mutableData:this.mutableData,parentModel:!0,instanceProps:n,forwardHostProp:function(e,t){let n=this.__instances;for(let s,r=0;r<n.length&&(s=n[r]);r++)s.forwardHostProp(e,t)},notifyInstanceProp:function(e,t,n){if((0,l.wB)(this.as,t)){let s=e[this.itemsIndexAs];t==this.as&&(this.items[s]=n);let r=(0,l.Iu)(this.as,`${JSCompiler_renameProperty("items",this)}.${s}`,t);this.notifyPath(r,n)}}})}return!0}__getMethodHost(){return this.__dataHost._methodHost||this.__dataHost}__functionFromPropertyValue(e){if("string"==typeof e){let t=e,n=this.__getMethodHost();return function(){return n[t].apply(n,arguments)}}return e}__sortChanged(e){this.__sortFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__filterChanged(e){this.__filterFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__computeFrameTime(e){return Math.ceil(1e3/e)}__observeChanged(){this.__observePaths=this.observe&&this.observe.replace(".*",".").split(" ")}__handleObservedPaths(e){if(this.__sortFn||this.__filterFn)if(e){if(this.__observePaths){let t=this.__observePaths;for(let n=0;n<t.length;n++)0===e.indexOf(t[n])&&this.__debounceRender(this.__render,this.delay)}}else this.__debounceRender(this.__render,this.delay)}__itemsChanged(e){this.items&&!Array.isArray(this.items)&&console.warn("dom-repeat expected array for `items`, found",this.items),this.__handleItemPath(e.path,e.value)||("items"===e.path&&(this.__itemsArrayChanged=!0),this.__debounceRender(this.__render))}__debounceRender(e,t=0){this.__renderDebouncer=i.dx.debounce(this.__renderDebouncer,t>0?d.Wc.after(t):d.YA,e.bind(this)),(0,o.E)(this.__renderDebouncer)}render(){this.__debounceRender(this.__render),(0,o.y)()}__render(){if(!this.__ensureTemplatized())return;let e=this.items||[];const t=this.__sortAndFilterItems(e),n=this.__calculateLimit(t.length);this.__updateInstances(e,n,t),this.initialCount&&(this.__shouldMeasureChunk||this.__shouldContinueChunking)&&(cancelAnimationFrame(this.__chunkingId),this.__chunkingId=requestAnimationFrame((()=>this.__continueChunking()))),this._setRenderedItemCount(this.__instances.length),p.dJ&&!this.notifyDomChange||this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0}))}__sortAndFilterItems(e){let t=new Array(e.length);for(let n=0;n<e.length;n++)t[n]=n;return this.__filterFn&&(t=t.filter(((t,n,s)=>this.__filterFn(e[t],n,s)))),this.__sortFn&&t.sort(((t,n)=>this.__sortFn(e[t],e[n]))),t}__calculateLimit(e){let t=e;const n=this.__instances.length;if(this.initialCount){let s;!this.__chunkCount||this.__itemsArrayChanged&&!this.reuseChunkedInstances?(t=Math.min(e,this.initialCount),s=Math.max(t-n,0),this.__chunkCount=s||1):(s=Math.min(Math.max(e-n,0),this.__chunkCount),t=Math.min(n+s,e)),this.__shouldMeasureChunk=s===this.__chunkCount,this.__shouldContinueChunking=t<e,this.__renderStartTime=performance.now()}return this.__itemsArrayChanged=!1,t}__continueChunking(){if(this.__shouldMeasureChunk){const e=performance.now()-this.__renderStartTime,t=this._targetFrameTime/e;this.__chunkCount=Math.round(this.__chunkCount*t)||1}this.__shouldContinueChunking&&this.__debounceRender(this.__render)}__updateInstances(e,t,n){const s=this.__itemsIdxToInstIdx={};let r;for(r=0;r<t;r++){let t=this.__instances[r],i=n[r],o=e[i];s[i]=r,t?(t._setPendingProperty(this.as,o),t._setPendingProperty(this.indexAs,r),t._setPendingProperty(this.itemsIndexAs,i),t._flushProperties()):this.__insertInstance(o,r,i)}for(let e=this.__instances.length-1;e>=r;e--)this.__detachAndRemoveInstance(e)}__detachInstance(e){let t=this.__instances[e];const n=(0,c.r)(t.root);for(let e=0;e<t.children.length;e++){let s=t.children[e];n.appendChild(s)}return t}__attachInstance(e,t){let n=this.__instances[e];t.insertBefore(n.root,this)}__detachAndRemoveInstance(e){this.__detachInstance(e),this.__instances.splice(e,1)}__stampInstance(e,t,n){let s={};return s[this.as]=e,s[this.indexAs]=t,s[this.itemsIndexAs]=n,new this.__ctor(s)}__insertInstance(e,t,n){const s=this.__stampInstance(e,t,n);let r=this.__instances[t+1],i=r?r.children[0]:this;return(0,c.r)((0,c.r)(this).parentNode).insertBefore(s.root,i),this.__instances[t]=s,s}_showHideChildren(e){for(let t=0;t<this.__instances.length;t++)this.__instances[t]._showHideChildren(e)}__handleItemPath(e,t){let n=e.slice(6),s=n.indexOf("."),r=s<0?n:n.substring(0,s);if(r==parseInt(r,10)){let e=s<0?"":n.substring(s+1);this.__handleObservedPaths(e);let i=this.__itemsIdxToInstIdx[r],o=this.__instances[i];if(o){let n=this.as+(e?"."+e:"");o._setPendingPropertyOrPath(n,t,!1,!0),o._flushProperties()}return!0}}itemForElement(e){let t=this.modelForElement(e);return t&&t[this.as]}indexForElement(e){let t=this.modelForElement(e);return t&&t[this.indexAs]}modelForElement(e){return(0,r.GJ)(this.template,e)}}customElements.define(_.is,_)},33367:(e,t,n)=>{n.d(t,{w:()=>u});var s=n(18890),r=n(74460);const i={attached:!0,detached:!0,ready:!0,created:!0,beforeRegister:!0,registered:!0,attributeChanged:!0,listeners:!0,hostAttributes:!0},o={attached:!0,detached:!0,ready:!0,created:!0,beforeRegister:!0,registered:!0,attributeChanged:!0,behaviors:!0,_noAccessors:!0},a=Object.assign({listeners:!0,hostAttributes:!0,properties:!0,observers:!0},o);function l(e,t,n,s){!function(e,t,n){const s=e._noAccessors,r=Object.getOwnPropertyNames(e);for(let i=0;i<r.length;i++){let o=r[i];if(!(o in n))if(s)t[o]=e[o];else{let n=Object.getOwnPropertyDescriptor(e,o);n&&(n.configurable=!0,Object.defineProperty(t,o,n))}}}(t,e,s);for(let e in i)t[e]&&(n[e]=n[e]||[],n[e].push(t[e]))}function d(e,t,n){t=t||[];for(let s=e.length-1;s>=0;s--){let r=e[s];r?Array.isArray(r)?d(r,t):t.indexOf(r)<0&&(!n||n.indexOf(r)<0)&&t.unshift(r):console.warn("behavior is null, check for missing or 404 import")}return t}function c(e,t){for(const n in t){const s=e[n],r=t[n];e[n]=!("value"in r)&&s&&"value"in s?Object.assign({value:s.value},r):r}}const h=(0,s.x)(HTMLElement);function p(e,t,n){let s;const i={};class h extends t{static _finalizeClass(){if(this.hasOwnProperty(JSCompiler_renameProperty("generatedFrom",this))){if(s)for(let e,t=0;t<s.length;t++)e=s[t],e.properties&&this.createProperties(e.properties),e.observers&&this.createObservers(e.observers,e.properties);e.properties&&this.createProperties(e.properties),e.observers&&this.createObservers(e.observers,e.properties),this._prepareTemplate()}else t._finalizeClass.call(this)}static get properties(){const t={};if(s)for(let e=0;e<s.length;e++)c(t,s[e].properties);return c(t,e.properties),t}static get observers(){let t=[];if(s)for(let e,n=0;n<s.length;n++)e=s[n],e.observers&&(t=t.concat(e.observers));return e.observers&&(t=t.concat(e.observers)),t}created(){super.created();const e=i.created;if(e)for(let t=0;t<e.length;t++)e[t].call(this)}_registered(){const e=h.prototype;if(!e.hasOwnProperty(JSCompiler_renameProperty("__hasRegisterFinished",e))){const t=Object.getPrototypeOf(this);t===e&&(e.__hasRegisterFinished=!0),super._registered(),r.nL&&!Object.hasOwnProperty(e,"__hasCopiedProperties")&&(e.__hasCopiedProperties=!0,p(e));let n=i.beforeRegister;if(n)for(let e=0;e<n.length;e++)n[e].call(t);if(n=i.registered,n)for(let e=0;e<n.length;e++)n[e].call(t)}}_applyListeners(){super._applyListeners();const e=i.listeners;if(e)for(let t=0;t<e.length;t++){const n=e[t];if(n)for(let e in n)this._addMethodEventListenerToNode(this,e,n[e])}}_ensureAttributes(){const e=i.hostAttributes;if(e)for(let t=e.length-1;t>=0;t--){const n=e[t];for(let e in n)this._ensureAttribute(e,n[e])}super._ensureAttributes()}ready(){super.ready();let e=i.ready;if(e)for(let t=0;t<e.length;t++)e[t].call(this)}attached(){super.attached();let e=i.attached;if(e)for(let t=0;t<e.length;t++)e[t].call(this)}detached(){super.detached();let e=i.detached;if(e)for(let t=0;t<e.length;t++)e[t].call(this)}attributeChanged(e,t,n){super.attributeChanged();let s=i.attributeChanged;if(s)for(let r=0;r<s.length;r++)s[r].call(this,e,t,n)}}if(n){Array.isArray(n)||(n=[n]);let e=t.prototype.behaviors;s=d(n,null,e),h.prototype.behaviors=e?e.concat(n):s}const p=t=>{s&&function(e,t,n){for(let s=0;s<t.length;s++)l(e,t[s],n,a)}(t,s,i),l(t,e,i,o)};return r.nL||p(h.prototype),h.generatedFrom=e,h}const u=function(e,t){e||console.warn("Polymer.Class requires `info` argument");let n=t?t(h):h;return n=p(e,n,e.behaviors),n.is=n.prototype.is=e.is,n}},18890:(e,t,n)=>{n.d(t,{x:()=>ve});var s=n(26539);class r{constructor(){this.start=0,this.end=0,this.previous=null,this.parent=null,this.rules=null,this.parsedCssText="",this.cssText="",this.atRule=!1,this.type=0,this.keyframesName="",this.selector="",this.parsedSelector=""}}function i(e){return o(function(e){let t=new r;t.start=0,t.end=e.length;let n=t;for(let s=0,i=e.length;s<i;s++)if(e[s]===d){n.rules||(n.rules=[]);let e=n,t=e.rules[e.rules.length-1]||null;n=new r,n.start=s+1,n.parent=e,n.previous=t,e.rules.push(n)}else e[s]===c&&(n.end=s+1,n=n.parent||t);return t}(e=e.replace(h.comments,"").replace(h.port,"")),e)}function o(e,t){let n=t.substring(e.start,e.end-1);if(e.parsedCssText=e.cssText=n.trim(),e.parent){let s=e.previous?e.previous.end:e.parent.start;n=t.substring(s,e.start-1),n=function(e){return e.replace(/\\([0-9a-f]{1,6})\s/gi,(function(){let e=arguments[1],t=6-e.length;for(;t--;)e="0"+e;return"\\"+e}))}(n),n=n.replace(h.multipleSpaces," "),n=n.substring(n.lastIndexOf(";")+1);let r=e.parsedSelector=e.selector=n.trim();e.atRule=0===r.indexOf(_),e.atRule?0===r.indexOf(u)?e.type=l.MEDIA_RULE:r.match(h.keyframesRule)&&(e.type=l.KEYFRAMES_RULE,e.keyframesName=e.selector.split(h.multipleSpaces).pop()):0===r.indexOf(p)?e.type=l.MIXIN_RULE:e.type=l.STYLE_RULE}let s=e.rules;if(s)for(let e,n=0,r=s.length;n<r&&(e=s[n]);n++)o(e,t);return e}function a(e,t,n=""){let s="";if(e.cssText||e.rules){let n=e.rules;if(n&&!function(e){let t=e[0];return Boolean(t)&&Boolean(t.selector)&&0===t.selector.indexOf(p)}(n))for(let e,r=0,i=n.length;r<i&&(e=n[r]);r++)s=a(e,t,s);else s=t?e.cssText:function(e){return function(e){return e.replace(h.mixinApply,"").replace(h.varApply,"")}(e=function(e){return e.replace(h.customProp,"").replace(h.mixinProp,"")}(e))}(e.cssText),s=s.trim(),s&&(s="  "+s+"\n")}return s&&(e.selector&&(n+=e.selector+" "+d+"\n"),n+=s,e.selector&&(n+=c+"\n\n")),n}const l={STYLE_RULE:1,KEYFRAMES_RULE:7,MEDIA_RULE:4,MIXIN_RULE:1e3},d="{",c="}",h={comments:/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,port:/@import[^;]*;/gim,customProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,mixinProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,mixinApply:/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,varApply:/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,keyframesRule:/^@[^\s]*keyframes/,multipleSpaces:/\s+/g},p="--",u="@media",_="@";var f=n(60309);const m=new Set;function y(e){const t=e.textContent;if(!m.has(t)){m.add(t);const e=document.createElement("style");e.setAttribute("shady-unscoped",""),e.textContent=t,document.head.appendChild(e)}}function g(e){return e.hasAttribute("shady-unscoped")}function b(e,t){return e?("string"==typeof e&&(e=i(e)),t&&P(e,t),a(e,s.rd)):""}function w(e){return!e.__cssRules&&e.textContent&&(e.__cssRules=i(e.textContent)),e.__cssRules||null}function P(e,t,n,s){if(!e)return;let r=!1,i=e.type;if(s&&i===l.MEDIA_RULE){let t=e.selector.match(f.mA);t&&(window.matchMedia(t[1]).matches||(r=!0))}i===l.STYLE_RULE?t(e):n&&i===l.KEYFRAMES_RULE?n(e):i===l.MIXIN_RULE&&(r=!0);let o=e.rules;if(o&&!r)for(let e,r=0,i=o.length;r<i&&(e=o[r]);r++)P(e,t,n,s)}function C(e,t){let n=0;for(let s=t,r=e.length;s<r;s++)if("("===e[s])n++;else if(")"===e[s]&&0==--n)return s;return-1}function v(e,t){let n=e.indexOf("var(");if(-1===n)return t(e,"","","");let s=C(e,n+3),r=e.substring(n+4,s),i=e.substring(0,n),o=v(e.substring(s+1),t),a=r.indexOf(",");return-1===a?t(i,r.trim(),"",o):t(i,r.substring(0,a).trim(),r.substring(a+1).trim(),o)}window.ShadyDOM&&window.ShadyDOM.wrap;const x="css-build";function S(e){if(void 0!==s.Cp)return s.Cp;if(void 0===e.__cssBuild){const t=e.getAttribute(x);if(t)e.__cssBuild=t;else{const t=function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;if(t instanceof Comment){const e=t.textContent.trim().split(":");if(e[0]===x)return e[1]}return""}(e);""!==t&&function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;t.parentNode.removeChild(t)}(e),e.__cssBuild=t}}return e.__cssBuild||""}function E(e){return""!==S(e)}var O=n(10868);const T=/;\s*/m,A=/^\s*(initial)|(inherit)\s*$/,N=/\s*!important/,I="_-_";class k{constructor(){this._map={}}set(e,t){e=e.trim(),this._map[e]={properties:t,dependants:{}}}get(e){return e=e.trim(),this._map[e]||null}}let M=null;class D{constructor(){this._currentElement=null,this._measureElement=null,this._map=new k}detectMixin(e){return(0,O.OH)(e)}gatherStyles(e){const t=function(e){const t=[],n=e.querySelectorAll("style");for(let e=0;e<n.length;e++){const r=n[e];g(r)?s.WA||(y(r),r.parentNode.removeChild(r)):(t.push(r.textContent),r.parentNode.removeChild(r))}return t.join("").trim()}(e.content);if(t){const n=document.createElement("style");return n.textContent=t,e.content.insertBefore(n,e.content.firstChild),n}return null}transformTemplate(e,t){void 0===e._gatheredStyle&&(e._gatheredStyle=this.gatherStyles(e));const n=e._gatheredStyle;return n?this.transformStyle(n,t):null}transformStyle(e,t=""){let n=w(e);return this.transformRules(n,t),e.textContent=b(n),n}transformCustomStyle(e){let t=w(e);return P(t,(e=>{":root"===e.selector&&(e.selector="html"),this.transformRule(e)})),e.textContent=b(t),t}transformRules(e,t){this._currentElement=t,P(e,(e=>{this.transformRule(e)})),this._currentElement=null}transformRule(e){e.cssText=this.transformCssText(e.parsedCssText,e),":root"===e.selector&&(e.selector=":host > *")}transformCssText(e,t){return e=e.replace(f.CN,((e,n,s,r)=>this._produceCssProperties(e,n,s,r,t))),this._consumeCssProperties(e,t)}_getInitialValueForProperty(e){return this._measureElement||(this._measureElement=document.createElement("meta"),this._measureElement.setAttribute("apply-shim-measure",""),this._measureElement.style.all="initial",document.head.appendChild(this._measureElement)),window.getComputedStyle(this._measureElement).getPropertyValue(e)}_fallbacksFromPreviousRules(e){let t=e;for(;t.parent;)t=t.parent;const n={};let s=!1;return P(t,(t=>{s=s||t===e,s||t.selector===e.selector&&Object.assign(n,this._cssTextToMap(t.parsedCssText))})),n}_consumeCssProperties(e,t){let n=null;for(;n=f.$T.exec(e);){let s=n[0],r=n[1],i=n.index,o=i+s.indexOf("@apply"),a=i+s.length,l=e.slice(0,o),d=e.slice(a),c=t?this._fallbacksFromPreviousRules(t):{};Object.assign(c,this._cssTextToMap(l));let h=this._atApplyToCssProperties(r,c);e=`${l}${h}${d}`,f.$T.lastIndex=i+h.length}return e}_atApplyToCssProperties(e,t){e=e.replace(T,"");let n=[],s=this._map.get(e);if(s||(this._map.set(e,{}),s=this._map.get(e)),s){let r,i,o;this._currentElement&&(s.dependants[this._currentElement]=!0);const a=s.properties;for(r in a)o=t&&t[r],i=[r,": var(",e,I,r],o&&i.push(",",o.replace(N,"")),i.push(")"),N.test(a[r])&&i.push(" !important"),n.push(i.join(""))}return n.join("; ")}_replaceInitialOrInherit(e,t){let n=A.exec(t);return n&&(t=n[1]?this._getInitialValueForProperty(e):"apply-shim-inherit"),t}_cssTextToMap(e,t=!1){let n,s,r=e.split(";"),i={};for(let e,o,a=0;a<r.length;a++)e=r[a],e&&(o=e.split(":"),o.length>1&&(n=o[0].trim(),s=o.slice(1).join(":"),t&&(s=this._replaceInitialOrInherit(n,s)),i[n]=s));return i}_invalidateMixinEntry(e){if(M)for(let t in e.dependants)t!==this._currentElement&&M(t)}_produceCssProperties(e,t,n,s,r){if(n&&v(n,((e,t)=>{t&&this._map.get(t)&&(s=`@apply ${t};`)})),!s)return e;let i=this._consumeCssProperties(""+s,r),o=e.slice(0,e.indexOf("--")),a=this._cssTextToMap(i,!0),l=a,d=this._map.get(t),c=d&&d.properties;c?l=Object.assign(Object.create(c),a):this._map.set(t,l);let h,p,u=[],_=!1;for(h in l)p=a[h],void 0===p&&(p="initial"),c&&!(h in c)&&(_=!0),u.push(`${t}_-_${h}: ${p}`);return _&&this._invalidateMixinEntry(d),d&&(d.properties=l),n&&(o=`${e};${o}`),`${o}${u.join("; ")};`}}D.prototype.detectMixin=D.prototype.detectMixin,D.prototype.transformStyle=D.prototype.transformStyle,D.prototype.transformCustomStyle=D.prototype.transformCustomStyle,D.prototype.transformRules=D.prototype.transformRules,D.prototype.transformRule=D.prototype.transformRule,D.prototype.transformTemplate=D.prototype.transformTemplate,D.prototype._separator=I,Object.defineProperty(D.prototype,"invalidCallback",{get:()=>M,set(e){M=e}});const R=D,L={},F="_applyShimCurrentVersion",H="_applyShimNextVersion",z="_applyShimValidatingVersion",j=Promise.resolve();function B(e){let t=L[e];t&&function(e){e[F]=e[F]||0,e[z]=e[z]||0,e[H]=(e[H]||0)+1}(t)}function U(e){return e[F]===e[H]}function $(e){return!U(e)&&e[z]===e[H]}function Y(e){e[z]=e[H],e._validating||(e._validating=!0,j.then((function(){e[F]=e[H],e._validating=!1})))}n(34816);const q=new R;class J{constructor(){this.customStyleInterface=null,q.invalidCallback=B}ensure(){this.customStyleInterface||window.ShadyCSS.CustomStyleInterface&&(this.customStyleInterface=window.ShadyCSS.CustomStyleInterface,this.customStyleInterface.transformCallback=e=>{q.transformCustomStyle(e)},this.customStyleInterface.validateCallback=()=>{requestAnimationFrame((()=>{this.customStyleInterface.enqueued&&this.flushCustomStyles()}))})}prepareTemplate(e,t){if(this.ensure(),E(e))return;L[t]=e;let n=q.transformTemplate(e,t);e._styleAst=n}flushCustomStyles(){if(this.ensure(),!this.customStyleInterface)return;let e=this.customStyleInterface.processStyles();if(this.customStyleInterface.enqueued){for(let t=0;t<e.length;t++){let n=e[t],s=this.customStyleInterface.getStyleForCustomStyle(n);s&&q.transformCustomStyle(s)}this.customStyleInterface.enqueued=!1}}styleSubtree(e,t){if(this.ensure(),t&&(0,O.wW)(e,t),e.shadowRoot){this.styleElement(e);let t=e.shadowRoot.children||e.shadowRoot.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}else{let t=e.children||e.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}}styleElement(e){this.ensure();let{is:t}=function(e){let t=e.localName,n="",s="";return t?t.indexOf("-")>-1?n=t:(s=t,n=e.getAttribute&&e.getAttribute("is")||""):(n=e.is,s=e.extends),{is:n,typeExtension:s}}(e),n=L[t];if((!n||!E(n))&&n&&!U(n)){$(n)||(this.prepareTemplate(n,t),Y(n));let s=e.shadowRoot;if(s){let e=s.querySelector("style");e&&(e.__cssRules=n._styleAst,e.textContent=b(n._styleAst))}}}styleDocument(e){this.ensure(),this.styleSubtree(document.body,e)}}if(!window.ShadyCSS||!window.ShadyCSS.ScopingShim){const e=new J;let t=window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface;window.ShadyCSS={prepareTemplate(t,n,s){e.flushCustomStyles(),e.prepareTemplate(t,n)},prepareTemplateStyles(e,t,n){window.ShadyCSS.prepareTemplate(e,t,n)},prepareTemplateDom(e,t){},styleSubtree(t,n){e.flushCustomStyles(),e.styleSubtree(t,n)},styleElement(t){e.flushCustomStyles(),e.styleElement(t)},styleDocument(t){e.flushCustomStyles(),e.styleDocument(t)},getComputedStyleValue:(e,t)=>(0,O.B7)(e,t),flushCustomStyles(){e.flushCustomStyles()},nativeCss:s.rd,nativeShadow:s.WA,cssBuild:s.Cp,disableRuntime:s.jF},t&&(window.ShadyCSS.CustomStyleInterface=t)}window.ShadyCSS.ApplyShim=q;var V=n(36608),X=n(60995),W=n(63933),G=n(76389);const Z=/:host\(:dir\((ltr|rtl)\)\)/g,K=/([\s\w-#\.\[\]\*]*):dir\((ltr|rtl)\)/g,Q=/:dir\((?:ltr|rtl)\)/,ee=Boolean(window.ShadyDOM&&window.ShadyDOM.inUse),te=[];let ne=null,se="";function re(){se=document.documentElement.getAttribute("dir")}function ie(e){if(!e.__autoDirOptOut){e.setAttribute("dir",se)}}function oe(){re(),se=document.documentElement.getAttribute("dir");for(let e=0;e<te.length;e++)ie(te[e])}const ae=(0,G.o)((e=>{ee||ne||(re(),ne=new MutationObserver(oe),ne.observe(document.documentElement,{attributes:!0,attributeFilter:["dir"]}));const t=(0,W.Q)(e);class n extends t{static _processStyleText(e,n){return e=t._processStyleText.call(this,e,n),!ee&&Q.test(e)&&(e=this._replaceDirInCssText(e),this.__activateDir=!0),e}static _replaceDirInCssText(e){let t=e;return t=t.replace(Z,':host([dir="$1"])'),t=t.replace(K,':host([dir="$2"]) $1'),t}constructor(){super(),this.__autoDirOptOut=!1}ready(){super.ready(),this.__autoDirOptOut=this.hasAttribute("dir")}connectedCallback(){t.prototype.connectedCallback&&super.connectedCallback(),this.constructor.__activateDir&&(ne&&ne.takeRecords().length&&oe(),te.push(this),ie(this))}disconnectedCallback(){if(t.prototype.disconnectedCallback&&super.disconnectedCallback(),this.constructor.__activateDir){const e=te.indexOf(this);e>-1&&te.splice(e,1)}}}return n.__activateDir=!1,n}));n(87529);function le(){document.body.removeAttribute("unresolved")}"interactive"===document.readyState||"complete"===document.readyState?le():window.addEventListener("DOMContentLoaded",le);var de=n(87156),ce=n(81668),he=n(78956),pe=n(21683),ue=n(4059),_e=n(62276);n(56646);const fe=window.ShadyDOM,me=window.ShadyCSS;function ye(e,t){return(0,_e.r)(e).getRootNode()===t}var ge=n(74460),be=n(16777),we=n(65412);const Pe="disable-upgrade";let Ce=window.ShadyCSS;const ve=(0,G.o)((e=>{const t=(0,X._)((0,V.SH)(e)),n=V.PP?t:ae(t),s=(0,be.X)(n),r={x:"pan-x",y:"pan-y",none:"none",all:"auto"};class i extends n{constructor(){super(),this.isAttached,this.__boundListeners,this._debouncers,this.__isUpgradeDisabled,this.__needsAttributesAtConnected,this._legacyForceObservedAttributes}static get importMeta(){return this.prototype.importMeta}created(){}__attributeReaction(e,t,n){(this.__dataAttributes&&this.__dataAttributes[e]||e===Pe)&&this.attributeChangedCallback(e,t,n,null)}setAttribute(e,t){if(ge.j8&&!this._legacyForceObservedAttributes){const n=this.getAttribute(e);super.setAttribute(e,t),this.__attributeReaction(e,n,String(t))}else super.setAttribute(e,t)}removeAttribute(e){if(ge.j8&&!this._legacyForceObservedAttributes){const t=this.getAttribute(e);super.removeAttribute(e),this.__attributeReaction(e,t,null)}else super.removeAttribute(e)}static get observedAttributes(){return ge.j8&&!this.prototype._legacyForceObservedAttributes?(this.hasOwnProperty(JSCompiler_renameProperty("__observedAttributes",this))||(this.__observedAttributes=[],(0,we.z2)(this.prototype)),this.__observedAttributes):s.call(this).concat(Pe)}_enableProperties(){this.__isUpgradeDisabled||super._enableProperties()}_canApplyPropertyDefault(e){return super._canApplyPropertyDefault(e)&&!(this.__isUpgradeDisabled&&this._isPropertyPending(e))}connectedCallback(){this.__needsAttributesAtConnected&&this._takeAttributes(),this.__isUpgradeDisabled||(super.connectedCallback(),this.isAttached=!0,this.attached())}attached(){}disconnectedCallback(){this.__isUpgradeDisabled||(super.disconnectedCallback(),this.isAttached=!1,this.detached())}detached(){}attributeChangedCallback(e,t,n,s){t!==n&&(e==Pe?this.__isUpgradeDisabled&&null==n&&(this._initializeProperties(),this.__isUpgradeDisabled=!1,(0,_e.r)(this).isConnected&&this.connectedCallback()):(super.attributeChangedCallback(e,t,n,s),this.attributeChanged(e,t,n)))}attributeChanged(e,t,n){}_initializeProperties(){if(ge.nL&&this.hasAttribute(Pe))this.__isUpgradeDisabled=!0;else{let e=Object.getPrototypeOf(this);e.hasOwnProperty(JSCompiler_renameProperty("__hasRegisterFinished",e))||(this._registered(),e.__hasRegisterFinished=!0),super._initializeProperties(),this.root=this,this.created(),ge.j8&&!this._legacyForceObservedAttributes&&(this.hasAttributes()?this._takeAttributes():this.parentNode||(this.__needsAttributesAtConnected=!0)),this._applyListeners()}}_takeAttributes(){const e=this.attributes;for(let t=0,n=e.length;t<n;t++){const n=e[t];this.__attributeReaction(n.name,null,n.value)}}_registered(){}ready(){this._ensureAttributes(),super.ready()}_ensureAttributes(){}_applyListeners(){}serialize(e){return this._serializeValue(e)}deserialize(e,t){return this._deserializeValue(e,t)}reflectPropertyToAttribute(e,t,n){this._propertyToAttribute(e,t,n)}serializeValueToAttribute(e,t,n){this._valueToNodeAttribute(n||this,e,t)}extend(e,t){if(!e||!t)return e||t;let n=Object.getOwnPropertyNames(t);for(let s,r=0;r<n.length&&(s=n[r]);r++){let n=Object.getOwnPropertyDescriptor(t,s);n&&Object.defineProperty(e,s,n)}return e}mixin(e,t){for(let n in t)e[n]=t[n];return e}chainObject(e,t){return e&&t&&e!==t&&(e.__proto__=t),e}instanceTemplate(e){let t=this.constructor._contentForTemplate(e);return document.importNode(t,!0)}fire(e,t,n){n=n||{},t=null==t?{}:t;let s=new Event(e,{bubbles:void 0===n.bubbles||n.bubbles,cancelable:Boolean(n.cancelable),composed:void 0===n.composed||n.composed});s.detail=t;let r=n.node||this;return(0,_e.r)(r).dispatchEvent(s),s}listen(e,t,n){e=e||this;let s=this.__boundListeners||(this.__boundListeners=new WeakMap),r=s.get(e);r||(r={},s.set(e,r));let i=t+n;r[i]||(r[i]=this._addMethodEventListenerToNode(e,t,n,this))}unlisten(e,t,n){e=e||this;let s=this.__boundListeners&&this.__boundListeners.get(e),r=t+n,i=s&&s[r];i&&(this._removeEventListenerFromNode(e,t,i),s[r]=null)}setScrollDirection(e,t){(0,ce.BP)(t||this,r[e]||"auto")}$$(e){return this.root.querySelector(e)}get domHost(){let e=(0,_e.r)(this).getRootNode();return e instanceof DocumentFragment?e.host:e}distributeContent(){const e=(0,de.vz)(this);window.ShadyDOM&&e.shadowRoot&&ShadyDOM.flush()}getEffectiveChildNodes(){return(0,de.vz)(this).getEffectiveChildNodes()}queryDistributedElements(e){return(0,de.vz)(this).queryDistributedElements(e)}getEffectiveChildren(){return this.getEffectiveChildNodes().filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}getEffectiveTextContent(){let e=this.getEffectiveChildNodes(),t=[];for(let n,s=0;n=e[s];s++)n.nodeType!==Node.COMMENT_NODE&&t.push(n.textContent);return t.join("")}queryEffectiveChildren(e){let t=this.queryDistributedElements(e);return t&&t[0]}queryAllEffectiveChildren(e){return this.queryDistributedElements(e)}getContentChildNodes(e){let t=this.root.querySelector(e||"slot");return t?(0,de.vz)(t).getDistributedNodes():[]}getContentChildren(e){return this.getContentChildNodes(e).filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}isLightDescendant(e){const t=this;return t!==e&&(0,_e.r)(t).contains(e)&&(0,_e.r)(t).getRootNode()===(0,_e.r)(e).getRootNode()}isLocalDescendant(e){return this.root===(0,_e.r)(e).getRootNode()}scopeSubtree(e,t=!1){return function(e,t=!1){if(!fe||!me)return null;if(!fe.handlesDynamicScoping)return null;const n=me.ScopingShim;if(!n)return null;const s=n.scopeForNode(e),r=(0,_e.r)(e).getRootNode(),i=e=>{if(!ye(e,r))return;const t=Array.from(fe.nativeMethods.querySelectorAll.call(e,"*"));t.push(e);for(let e=0;e<t.length;e++){const i=t[e];if(!ye(i,r))continue;const o=n.currentScopeForNode(i);o!==s&&(""!==o&&n.unscopeNode(i,o),n.scopeNode(i,s))}};if(i(e),t){const t=new MutationObserver((e=>{for(let t=0;t<e.length;t++){const n=e[t];for(let e=0;e<n.addedNodes.length;e++){const t=n.addedNodes[e];t.nodeType===Node.ELEMENT_NODE&&i(t)}}}));return t.observe(e,{childList:!0,subtree:!0}),t}return null}(e,t)}getComputedStyleValue(e){return Ce.getComputedStyleValue(this,e)}debounce(e,t,n){return this._debouncers=this._debouncers||{},this._debouncers[e]=he.dx.debounce(this._debouncers[e],n>0?pe.Wc.after(n):pe.YA,t.bind(this))}isDebouncerActive(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];return!(!t||!t.isActive())}flushDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.flush()}cancelDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.cancel()}async(e,t){return t>0?pe.Wc.run(e.bind(this),t):~pe.YA.run(e.bind(this))}cancelAsync(e){e<0?pe.YA.cancel(~e):pe.Wc.cancel(e)}create(e,t){let n=document.createElement(e);if(t)if(n.setProperties)n.setProperties(t);else for(let e in t)n[e]=t[e];return n}elementMatches(e,t){return(0,de.Ku)(t||this,e)}toggleAttribute(e,t){let n=this;return 3===arguments.length&&(n=arguments[2]),1==arguments.length&&(t=!n.hasAttribute(e)),t?((0,_e.r)(n).setAttribute(e,""),!0):((0,_e.r)(n).removeAttribute(e),!1)}toggleClass(e,t,n){n=n||this,1==arguments.length&&(t=!n.classList.contains(e)),t?n.classList.add(e):n.classList.remove(e)}transform(e,t){(t=t||this).style.webkitTransform=e,t.style.transform=e}translate3d(e,t,n,s){s=s||this,this.transform("translate3d("+e+","+t+","+n+")",s)}arrayDelete(e,t){let n;if(Array.isArray(e)){if(n=e.indexOf(t),n>=0)return e.splice(n,1)}else{if(n=(0,ue.U2)(this,e).indexOf(t),n>=0)return this.splice(e,n,1)}return null}_logger(e,t){switch(Array.isArray(t)&&1===t.length&&Array.isArray(t[0])&&(t=t[0]),e){case"log":case"warn":case"error":console[e](...t)}}_log(...e){this._logger("log",e)}_warn(...e){this._logger("warn",e)}_error(...e){this._logger("error",e)}_logf(e,...t){return["[%s::%s]",this.is,e,...t]}}return i.prototype.is="",i}))},72419:(e,t,n)=>{var s=n(18691);let r;r=s.E._mutablePropertyChange;Boolean},9672:(e,t,n)=>{var s=n(33367);n(56646);const r=function(e){let t;return t="function"==typeof e?e:r.Class(e),e._legacyForceObservedAttributes&&(t.prototype._legacyForceObservedAttributes=e._legacyForceObservedAttributes),customElements.define(t.is,t),t};r.Class=s.w},87156:(e,t,n)=>{n.d(t,{Ku:()=>a,vz:()=>p});n(56646);var s=n(62276),r=(n(74460),n(20723));n(93252),n(78956);const i=Element.prototype,o=i.matches||i.matchesSelector||i.mozMatchesSelector||i.msMatchesSelector||i.oMatchesSelector||i.webkitMatchesSelector,a=function(e,t){return o.call(e,t)};class l{constructor(e){window.ShadyDOM&&window.ShadyDOM.inUse&&window.ShadyDOM.patch(e),this.node=e}observeNodes(e){return new r.o(this.node,e)}unobserveNodes(e){e.disconnect()}notifyObserver(){}deepContains(e){if((0,s.r)(this.node).contains(e))return!0;let t=e,n=e.ownerDocument;for(;t&&t!==n&&t!==this.node;)t=(0,s.r)(t).parentNode||(0,s.r)(t).host;return t===this.node}getOwnerRoot(){return(0,s.r)(this.node).getRootNode()}getDistributedNodes(){return"slot"===this.node.localName?(0,s.r)(this.node).assignedNodes({flatten:!0}):[]}getDestinationInsertionPoints(){let e=[],t=(0,s.r)(this.node).assignedSlot;for(;t;)e.push(t),t=(0,s.r)(t).assignedSlot;return e}importNode(e,t){let n=this.node instanceof Document?this.node:this.node.ownerDocument;return(0,s.r)(n).importNode(e,t)}getEffectiveChildNodes(){return r.o.getFlattenedNodes(this.node)}queryDistributedElements(e){let t=this.getEffectiveChildNodes(),n=[];for(let s,r=0,i=t.length;r<i&&(s=t[r]);r++)s.nodeType===Node.ELEMENT_NODE&&a(s,e)&&n.push(s);return n}get activeElement(){let e=this.node;return void 0!==e._activeElement?e._activeElement:e.activeElement}}function d(e,t){for(let n=0;n<t.length;n++){let s=t[n];Object.defineProperty(e,s,{get:function(){return this.node[s]},configurable:!0})}}class c{constructor(e){this.event=e}get rootTarget(){return this.path[0]}get localTarget(){return this.event.target}get path(){return this.event.composedPath()}}l.prototype.cloneNode,l.prototype.appendChild,l.prototype.insertBefore,l.prototype.removeChild,l.prototype.replaceChild,l.prototype.setAttribute,l.prototype.removeAttribute,l.prototype.querySelector,l.prototype.querySelectorAll,l.prototype.parentNode,l.prototype.firstChild,l.prototype.lastChild,l.prototype.nextSibling,l.prototype.previousSibling,l.prototype.firstElementChild,l.prototype.lastElementChild,l.prototype.nextElementSibling,l.prototype.previousElementSibling,l.prototype.childNodes,l.prototype.children,l.prototype.classList,l.prototype.textContent,l.prototype.innerHTML;let h=l;if(window.ShadyDOM&&window.ShadyDOM.inUse&&window.ShadyDOM.noPatch&&window.ShadyDOM.Wrapper){class e extends window.ShadyDOM.Wrapper{}Object.getOwnPropertyNames(l.prototype).forEach((t=>{"activeElement"!=t&&(e.prototype[t]=l.prototype[t])})),d(e.prototype,["classList"]),h=e,Object.defineProperties(c.prototype,{localTarget:{get(){const e=this.event.currentTarget,t=e&&p(e).getOwnerRoot(),n=this.path;for(let e=0;e<n.length;e++){const s=n[e];if(p(s).getOwnerRoot()===t)return s}},configurable:!0},path:{get(){return window.ShadyDOM.composedPath(this.event)},configurable:!0}})}else!function(e,t){for(let n=0;n<t.length;n++){let s=t[n];e[s]=function(){return this.node[s].apply(this.node,arguments)}}}(l.prototype,["cloneNode","appendChild","insertBefore","removeChild","replaceChild","setAttribute","removeAttribute","querySelector","querySelectorAll"]),d(l.prototype,["parentNode","firstChild","lastChild","nextSibling","previousSibling","firstElementChild","lastElementChild","nextElementSibling","previousElementSibling","childNodes","children","classList"]),function(e,t){for(let n=0;n<t.length;n++){let s=t[n];Object.defineProperty(e,s,{get:function(){return this.node[s]},set:function(e){this.node[s]=e},configurable:!0})}}(l.prototype,["textContent","innerHTML","className"]);const p=function(e){if((e=e||document)instanceof h)return e;if(e instanceof c)return e;let t=e.__domApi;return t||(t=e instanceof Event?new c(e):new h(e),e.__domApi=t),t}},37692:(e,t,n)=>{n(52521)},16777:(e,t,n)=>{n.d(t,{X:()=>a});var s=n(36608),r=n(76389),i=n(62276);const o="disable-upgrade",a=e=>{for(;e;){const t=Object.getOwnPropertyDescriptor(e,"observedAttributes");if(t)return t.get;e=Object.getPrototypeOf(e.prototype).constructor}return()=>[]};(0,r.o)((e=>{const t=(0,s.SH)(e);let n=a(t);return class extends t{constructor(){super(),this.__isUpgradeDisabled}static get observedAttributes(){return n.call(this).concat(o)}_initializeProperties(){this.hasAttribute(o)?this.__isUpgradeDisabled=!0:super._initializeProperties()}_enableProperties(){this.__isUpgradeDisabled||super._enableProperties()}_canApplyPropertyDefault(e){return super._canApplyPropertyDefault(e)&&!(this.__isUpgradeDisabled&&this._isPropertyPending(e))}attributeChangedCallback(e,t,n,s){e==o?this.__isUpgradeDisabled&&null==n&&(super._initializeProperties(),this.__isUpgradeDisabled=!1,(0,i.r)(this).isConnected&&super.connectedCallback()):super.attributeChangedCallback(e,t,n,s)}connectedCallback(){this.__isUpgradeDisabled||super.connectedCallback()}disconnectedCallback(){this.__isUpgradeDisabled||super.disconnectedCallback()}}}))},36608:(e,t,n)=>{n.d(t,{SH:()=>_,PP:()=>u});n(56646);var s=n(74460),r=n(76389),i=n(15392),o=n(42687),a=n(21384),l=n(40729),d=n(65412),c=n(24072);const h=(0,r.o)((e=>{const t=(0,c.e)(e);function n(e){const t=Object.getPrototypeOf(e);return t.prototype instanceof r?t:null}function s(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__ownProperties",e))){let t=null;if(e.hasOwnProperty(JSCompiler_renameProperty("properties",e))){const n=e.properties;n&&(t=function(e){const t={};for(let n in e){const s=e[n];t[n]="function"==typeof s?{type:s}:s}return t}(n))}e.__ownProperties=t}return e.__ownProperties}class r extends t{static get observedAttributes(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__observedAttributes",this))){(0,d.z2)(this.prototype);const e=this._properties;this.__observedAttributes=e?Object.keys(e).map((e=>this.prototype._addPropertyToAttributeMap(e))):[]}return this.__observedAttributes}static finalize(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__finalized",this))){const e=n(this);e&&e.finalize(),this.__finalized=!0,this._finalizeClass()}}static _finalizeClass(){const e=s(this);e&&this.createProperties(e)}static get _properties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__properties",this))){const e=n(this);this.__properties=Object.assign({},e&&e._properties,s(this))}return this.__properties}static typeForProperty(e){const t=this._properties[e];return t&&t.type}_initializeProperties(){(0,d.Gd)(),this.constructor.finalize(),super._initializeProperties()}connectedCallback(){super.connectedCallback&&super.connectedCallback(),this._enableProperties()}disconnectedCallback(){super.disconnectedCallback&&super.disconnectedCallback()}}return r}));var p=n(62276);const u=window.ShadyCSS&&window.ShadyCSS.cssBuild,_=(0,r.o)((e=>{const t=h((0,l.q)(e));return class extends t{static get polymerElementVersion(){return"3.4.1"}static _finalizeClass(){t._finalizeClass.call(this);const e=((n=this).hasOwnProperty(JSCompiler_renameProperty("__ownObservers",n))||(n.__ownObservers=n.hasOwnProperty(JSCompiler_renameProperty("observers",n))?n.observers:null),n.__ownObservers);var n;e&&this.createObservers(e,this._properties),this._prepareTemplate()}static _prepareTemplate(){let e=this.template;e&&("string"==typeof e?(console.error("template getter must return HTMLTemplateElement"),e=null):s.nL||(e=e.cloneNode(!0))),this.prototype._template=e}static createProperties(e){for(let i in e)t=this.prototype,n=i,s=e[i],r=e,s.computed&&(s.readOnly=!0),s.computed&&(t._hasReadOnlyEffect(n)?console.warn(`Cannot redefine computed property '${n}'.`):t._createComputedProperty(n,s.computed,r)),s.readOnly&&!t._hasReadOnlyEffect(n)?t._createReadOnlyProperty(n,!s.computed):!1===s.readOnly&&t._hasReadOnlyEffect(n)&&console.warn(`Cannot make readOnly property '${n}' non-readOnly.`),s.reflectToAttribute&&!t._hasReflectEffect(n)?t._createReflectedProperty(n):!1===s.reflectToAttribute&&t._hasReflectEffect(n)&&console.warn(`Cannot make reflected property '${n}' non-reflected.`),s.notify&&!t._hasNotifyEffect(n)?t._createNotifyingProperty(n):!1===s.notify&&t._hasNotifyEffect(n)&&console.warn(`Cannot make notify property '${n}' non-notify.`),s.observer&&t._createPropertyObserver(n,s.observer,r[s.observer]),t._addPropertyToAttributeMap(n);var t,n,s,r}static createObservers(e,t){const n=this.prototype;for(let s=0;s<e.length;s++)n._createMethodObserver(e[s],t)}static get template(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_template",this))){const e=this.prototype.hasOwnProperty(JSCompiler_renameProperty("_template",this.prototype))?this.prototype._template:void 0;this._template=void 0!==e?e:this.hasOwnProperty(JSCompiler_renameProperty("is",this))&&function(e){let t=null;if(e&&(!s.XN||s.ZN)&&(t=a.t.import(e,"template"),s.XN&&!t))throw new Error(`strictTemplatePolicy: expecting dom-module or null template for ${e}`);return t}(this.is)||Object.getPrototypeOf(this.prototype).constructor.template}return this._template}static set template(e){this._template=e}static get importPath(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_importPath",this))){const e=this.importMeta;if(e)this._importPath=(0,o.iY)(e.url);else{const e=a.t.import(this.is);this._importPath=e&&e.assetpath||Object.getPrototypeOf(this.prototype).constructor.importPath}}return this._importPath}constructor(){super(),this._template,this._importPath,this.rootPath,this.importPath,this.root,this.$}_initializeProperties(){this.constructor.finalize(),this.constructor._finalizeTemplate(this.localName),super._initializeProperties(),this.rootPath=s.sM,this.importPath=this.constructor.importPath;let e=function(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__propertyDefaults",e))){e.__propertyDefaults=null;let t=e._properties;for(let n in t){let s=t[n];"value"in s&&(e.__propertyDefaults=e.__propertyDefaults||{},e.__propertyDefaults[n]=s)}}return e.__propertyDefaults}(this.constructor);if(e)for(let t in e){let n=e[t];if(this._canApplyPropertyDefault(t)){let e="function"==typeof n.value?n.value.call(this):n.value;this._hasAccessor(t)?this._setPendingProperty(t,e,!0):this[t]=e}}}_canApplyPropertyDefault(e){return!this.hasOwnProperty(e)}static _processStyleText(e,t){return(0,o.Rq)(e,t)}static _finalizeTemplate(e){const t=this.prototype._template;if(t&&!t.__polymerFinalized){t.__polymerFinalized=!0;const n=this.importPath;!function(e,t,n,r){if(!u){const s=t.content.querySelectorAll("style"),o=(0,i.uT)(t),a=(0,i.lx)(n),l=t.content.firstElementChild;for(let n=0;n<a.length;n++){let s=a[n];s.textContent=e._processStyleText(s.textContent,r),t.content.insertBefore(s,l)}let d=0;for(let t=0;t<o.length;t++){let n=o[t],i=s[d];i!==n?(n=n.cloneNode(!0),i.parentNode.insertBefore(n,i)):d++,n.textContent=e._processStyleText(n.textContent,r)}}if(window.ShadyCSS&&window.ShadyCSS.prepareTemplate(t,n),s.md&&u&&s.FV){const n=t.content.querySelectorAll("style");if(n){let t="";Array.from(n).forEach((e=>{t+=e.textContent,e.parentNode.removeChild(e)})),e._styleSheet=new CSSStyleSheet,e._styleSheet.replaceSync(t)}}}(this,t,e,n?(0,o.Kk)(n):""),this.prototype._bindTemplate(t)}}connectedCallback(){window.ShadyCSS&&this._template&&window.ShadyCSS.styleElement(this),super.connectedCallback()}ready(){this._template&&(this.root=this._stampTemplate(this._template),this.$=this.root.$),super.ready()}_readyClients(){this._template&&(this.root=this._attachDom(this.root)),super._readyClients()}_attachDom(e){const t=(0,p.r)(this);if(t.attachShadow)return e?(t.shadowRoot||(t.attachShadow({mode:"open",shadyUpgradeFragment:e}),t.shadowRoot.appendChild(e),this.constructor._styleSheet&&(t.shadowRoot.adoptedStyleSheets=[this.constructor._styleSheet])),s.Hr&&window.ShadyDOM&&window.ShadyDOM.flushInitial(t.shadowRoot),t.shadowRoot):null;throw new Error("ShadowDOM not available. PolymerElement can create dom as children instead of in ShadowDOM by setting `this.root = this;` before `ready`.")}updateStyles(e){window.ShadyCSS&&window.ShadyCSS.styleSubtree(this,e)}resolveUrl(e,t){return!t&&this.importPath&&(t=(0,o.Kk)(this.importPath)),(0,o.Kk)(e,t)}static _parseTemplateContent(e,n,s){return n.dynamicFns=n.dynamicFns||this._properties,t._parseTemplateContent.call(this,e,n,s)}static _addTemplatePropertyEffect(e,n,r){return!s.a2||n in this._properties||r.info.part.signature&&r.info.part.signature.static||r.info.part.hostProp||e.nestedTemplate||console.warn(`Property '${n}' used in template but not declared in 'properties'; attribute will not be observed.`),t._addTemplatePropertyEffect.call(this,e,n,r)}}}))},60995:(e,t,n)=>{n.d(t,{_:()=>i});n(56646);var s=n(76389),r=n(81668);const i=(0,s.o)((e=>class extends e{_addEventListenerToNode(e,t,n){(0,r.NH)(e,t,n)||super._addEventListenerToNode(e,t,n)}_removeEventListenerFromNode(e,t,n){(0,r.ys)(e,t,n)||super._removeEventListenerFromNode(e,t,n)}}))},18691:(e,t,n)=>{n.d(t,{E:()=>i,w:()=>o});var s=n(76389);function r(e,t,n,s,r){let i;r&&(i="object"==typeof n&&null!==n,i&&(s=e.__dataTemp[t]));let o=s!==n&&(s==s||n==n);return i&&o&&(e.__dataTemp[t]=n),o}const i=(0,s.o)((e=>class extends e{_shouldPropertyChange(e,t,n){return r(this,e,t,n,!0)}})),o=(0,s.o)((e=>class extends e{static get properties(){return{mutableData:Boolean}}_shouldPropertyChange(e,t,n){return r(this,e,t,n,this.mutableData)}}));i._mutablePropertyChange=r},24072:(e,t,n)=>{n.d(t,{e:()=>a});n(56646);var s=n(76389),r=n(21683),i=n(62276);const o=r.YA,a=(0,s.o)((e=>class extends e{static createProperties(e){const t=this.prototype;for(let n in e)n in t||t._createPropertyAccessor(n)}static attributeNameForProperty(e){return e.toLowerCase()}static typeForProperty(e){}_createPropertyAccessor(e,t){this._addPropertyToAttributeMap(e),this.hasOwnProperty(JSCompiler_renameProperty("__dataHasAccessor",this))||(this.__dataHasAccessor=Object.assign({},this.__dataHasAccessor)),this.__dataHasAccessor[e]||(this.__dataHasAccessor[e]=!0,this._definePropertyAccessor(e,t))}_addPropertyToAttributeMap(e){this.hasOwnProperty(JSCompiler_renameProperty("__dataAttributes",this))||(this.__dataAttributes=Object.assign({},this.__dataAttributes));let t=this.__dataAttributes[e];return t||(t=this.constructor.attributeNameForProperty(e),this.__dataAttributes[t]=e),t}_definePropertyAccessor(e,t){Object.defineProperty(this,e,{get(){return this.__data[e]},set:t?function(){}:function(t){this._setPendingProperty(e,t,!0)&&this._invalidateProperties()}})}constructor(){super(),this.__dataEnabled=!1,this.__dataReady=!1,this.__dataInvalid=!1,this.__data={},this.__dataPending=null,this.__dataOld=null,this.__dataInstanceProps=null,this.__dataCounter=0,this.__serializing=!1,this._initializeProperties()}ready(){this.__dataReady=!0,this._flushProperties()}_initializeProperties(){for(let e in this.__dataHasAccessor)this.hasOwnProperty(e)&&(this.__dataInstanceProps=this.__dataInstanceProps||{},this.__dataInstanceProps[e]=this[e],delete this[e])}_initializeInstanceProperties(e){Object.assign(this,e)}_setProperty(e,t){this._setPendingProperty(e,t)&&this._invalidateProperties()}_getProperty(e){return this.__data[e]}_setPendingProperty(e,t,n){let s=this.__data[e],r=this._shouldPropertyChange(e,t,s);return r&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),this.__dataOld&&!(e in this.__dataOld)&&(this.__dataOld[e]=s),this.__data[e]=t,this.__dataPending[e]=t),r}_isPropertyPending(e){return!(!this.__dataPending||!this.__dataPending.hasOwnProperty(e))}_invalidateProperties(){!this.__dataInvalid&&this.__dataReady&&(this.__dataInvalid=!0,o.run((()=>{this.__dataInvalid&&(this.__dataInvalid=!1,this._flushProperties())})))}_enableProperties(){this.__dataEnabled||(this.__dataEnabled=!0,this.__dataInstanceProps&&(this._initializeInstanceProperties(this.__dataInstanceProps),this.__dataInstanceProps=null),this.ready())}_flushProperties(){this.__dataCounter++;const e=this.__data,t=this.__dataPending,n=this.__dataOld;this._shouldPropertiesChange(e,t,n)&&(this.__dataPending=null,this.__dataOld=null,this._propertiesChanged(e,t,n)),this.__dataCounter--}_shouldPropertiesChange(e,t,n){return Boolean(t)}_propertiesChanged(e,t,n){}_shouldPropertyChange(e,t,n){return n!==t&&(n==n||t==t)}attributeChangedCallback(e,t,n,s){t!==n&&this._attributeToProperty(e,n),super.attributeChangedCallback&&super.attributeChangedCallback(e,t,n,s)}_attributeToProperty(e,t,n){if(!this.__serializing){const s=this.__dataAttributes,r=s&&s[e]||e;this[r]=this._deserializeValue(t,n||this.constructor.typeForProperty(r))}}_propertyToAttribute(e,t,n){this.__serializing=!0,n=arguments.length<3?this[e]:n,this._valueToNodeAttribute(this,n,t||this.constructor.attributeNameForProperty(e)),this.__serializing=!1}_valueToNodeAttribute(e,t,n){const s=this._serializeValue(t);"class"!==n&&"name"!==n&&"slot"!==n||(e=(0,i.r)(e)),void 0===s?e.removeAttribute(n):e.setAttribute(n,s)}_serializeValue(e){return"boolean"==typeof e?e?"":void 0:null!=e?e.toString():void 0}_deserializeValue(e,t){switch(t){case Boolean:return null!==e;case Number:return Number(e);default:return e}}}))},63933:(e,t,n)=>{n.d(t,{Q:()=>l});n(56646);var s=n(76389),r=n(67130),i=n(24072);const o={};let a=HTMLElement.prototype;for(;a;){let e=Object.getOwnPropertyNames(a);for(let t=0;t<e.length;t++)o[e[t]]=!0;a=Object.getPrototypeOf(a)}const l=(0,s.o)((e=>{const t=(0,i.e)(e);return class extends t{static createPropertiesForAttributes(){let e=this.observedAttributes;for(let t=0;t<e.length;t++)this.prototype._createPropertyAccessor((0,r.z)(e[t]))}static attributeNameForProperty(e){return(0,r.n)(e)}_initializeProperties(){this.__dataProto&&(this._initializeProtoProperties(this.__dataProto),this.__dataProto=null),super._initializeProperties()}_initializeProtoProperties(e){for(let t in e)this._setProperty(t,e[t])}_ensureAttribute(e,t){const n=this;n.hasAttribute(e)||this._valueToNodeAttribute(n,t,e)}_serializeValue(e){if("object"==typeof e){if(e instanceof Date)return e.toString();if(e)try{return JSON.stringify(e)}catch(e){return""}}return super._serializeValue(e)}_deserializeValue(e,t){let n;switch(t){case Object:try{n=JSON.parse(e)}catch(t){n=e}break;case Array:try{n=JSON.parse(e)}catch(t){n=null,console.warn(`Polymer::Attributes: couldn't decode Array as JSON: ${e}`)}break;case Date:n=isNaN(e)?String(e):Number(e),n=new Date(n);break;default:n=super._deserializeValue(e,t)}return n}_definePropertyAccessor(e,t){!function(e,t){if(!o[t]){let n=e[t];void 0!==n&&(e.__data?e._setPendingProperty(t,n):(e.__dataProto?e.hasOwnProperty(JSCompiler_renameProperty("__dataProto",e))||(e.__dataProto=Object.create(e.__dataProto)):e.__dataProto={},e.__dataProto[t]=n))}}(this,e),super._definePropertyAccessor(e,t)}_hasAccessor(e){return this.__dataHasAccessor&&this.__dataHasAccessor[e]}_isPropertyPending(e){return Boolean(this.__dataPending&&e in this.__dataPending)}}}))},40729:(e,t,n)=>{n.d(t,{q:()=>K});n(56646);var s=n(62276),r=n(76389),i=n(4059),o=n(67130),a=n(63933);const l={"dom-if":!0,"dom-repeat":!0};let d=!1,c=!1;function h(e){(function(){if(!d){d=!0;const e=document.createElement("textarea");e.placeholder="a",c=e.placeholder===e.textContent}return c})()&&"textarea"===e.localName&&e.placeholder&&e.placeholder===e.textContent&&(e.textContent=null)}function p(e){let t=e.getAttribute("is");if(t&&l[t]){let n=e;for(n.removeAttribute("is"),e=n.ownerDocument.createElement(t),n.parentNode.replaceChild(e,n),e.appendChild(n);n.attributes.length;)e.setAttribute(n.attributes[0].name,n.attributes[0].value),n.removeAttribute(n.attributes[0].name)}return e}function u(e,t){let n=t.parentInfo&&u(e,t.parentInfo);if(!n)return e;for(let e=n.firstChild,s=0;e;e=e.nextSibling)if(t.parentIndex===s++)return e}function _(e,t,n,s){s.id&&(t[s.id]=n)}function f(e,t,n){if(n.events&&n.events.length)for(let s,r=0,i=n.events;r<i.length&&(s=i[r]);r++)e._addMethodEventListenerToNode(t,s.name,s.value,e)}function m(e,t,n,s){n.templateInfo&&(t._templateInfo=n.templateInfo,t._parentTemplateInfo=s)}const y=(0,r.o)((e=>class extends e{static _parseTemplate(e,t){if(!e._templateInfo){let n=e._templateInfo={};n.nodeInfoList=[],n.nestedTemplate=Boolean(t),n.stripWhiteSpace=t&&t.stripWhiteSpace||e.hasAttribute("strip-whitespace"),this._parseTemplateContent(e,n,{parent:null})}return e._templateInfo}static _parseTemplateContent(e,t,n){return this._parseTemplateNode(e.content,t,n)}static _parseTemplateNode(e,t,n){let s=!1,r=e;return"template"!=r.localName||r.hasAttribute("preserve-content")?"slot"===r.localName&&(t.hasInsertionPoint=!0):s=this._parseTemplateNestedTemplate(r,t,n)||s,h(r),r.firstChild&&this._parseTemplateChildNodes(r,t,n),r.hasAttributes&&r.hasAttributes()&&(s=this._parseTemplateNodeAttributes(r,t,n)||s),s||n.noted}static _parseTemplateChildNodes(e,t,n){if("script"!==e.localName&&"style"!==e.localName)for(let s,r=e.firstChild,i=0;r;r=s){if("template"==r.localName&&(r=p(r)),s=r.nextSibling,r.nodeType===Node.TEXT_NODE){let n=s;for(;n&&n.nodeType===Node.TEXT_NODE;)r.textContent+=n.textContent,s=n.nextSibling,e.removeChild(n),n=s;if(t.stripWhiteSpace&&!r.textContent.trim()){e.removeChild(r);continue}}let o={parentIndex:i,parentInfo:n};this._parseTemplateNode(r,t,o)&&(o.infoIndex=t.nodeInfoList.push(o)-1),r.parentNode&&i++}}static _parseTemplateNestedTemplate(e,t,n){let s=e,r=this._parseTemplate(s,t);return(r.content=s.content.ownerDocument.createDocumentFragment()).appendChild(s.content),n.templateInfo=r,!0}static _parseTemplateNodeAttributes(e,t,n){let s=!1,r=Array.from(e.attributes);for(let i,o=r.length-1;i=r[o];o--)s=this._parseTemplateNodeAttribute(e,t,n,i.name,i.value)||s;return s}static _parseTemplateNodeAttribute(e,t,n,s,r){return"on-"===s.slice(0,3)?(e.removeAttribute(s),n.events=n.events||[],n.events.push({name:s.slice(3),value:r}),!0):"id"===s&&(n.id=r,!0)}static _contentForTemplate(e){let t=e._templateInfo;return t&&t.content||e.content}_stampTemplate(e,t){e&&!e.content&&window.HTMLTemplateElement&&HTMLTemplateElement.decorate&&HTMLTemplateElement.decorate(e);let n=(t=t||this.constructor._parseTemplate(e)).nodeInfoList,s=t.content||e.content,r=document.importNode(s,!0);r.__noInsertionPoint=!t.hasInsertionPoint;let i=r.nodeList=new Array(n.length);r.$={};for(let e,s=0,o=n.length;s<o&&(e=n[s]);s++){let n=i[s]=u(r,e);_(0,r.$,n,e),m(0,n,e,t),f(this,n,e)}return r=r,r}_addMethodEventListenerToNode(e,t,n,s){let r=function(e,t,n){return e=e._methodHost||e,function(t){e[n]?e[n](t,t.detail):console.warn("listener method `"+n+"` not defined")}}(s=s||e,0,n);return this._addEventListenerToNode(e,t,r),r}_addEventListenerToNode(e,t,n){e.addEventListener(t,n)}_removeEventListenerFromNode(e,t,n){e.removeEventListener(t,n)}}));var g=n(74460);let b=0;const w=[],P={COMPUTE:"__computeEffects",REFLECT:"__reflectEffects",NOTIFY:"__notifyEffects",PROPAGATE:"__propagateEffects",OBSERVE:"__observeEffects",READ_ONLY:"__readOnly"},C="__computeInfo",v=/[A-Z]/;function x(e,t,n){let s=e[t];if(s){if(!e.hasOwnProperty(t)&&(s=e[t]=Object.create(e[t]),n))for(let e in s){let t=s[e],n=s[e]=Array(t.length);for(let e=0;e<t.length;e++)n[e]=t[e]}}else s=e[t]={};return s}function S(e,t,n,s,r,o){if(t){let a=!1;const l=b++;for(let d in n){let c=t[r?(0,i.Jz)(d):d];if(c)for(let t,i=0,h=c.length;i<h&&(t=c[i]);i++)t.info&&t.info.lastRun===l||r&&!O(d,t.trigger)||(t.info&&(t.info.lastRun=l),t.fn(e,d,n,s,t.info,r,o),a=!0)}return a}return!1}function E(e,t,n,s,r,o,a,l){let d=!1,c=t[a?(0,i.Jz)(s):s];if(c)for(let t,i=0,h=c.length;i<h&&(t=c[i]);i++)t.info&&t.info.lastRun===n||a&&!O(s,t.trigger)||(t.info&&(t.info.lastRun=n),t.fn(e,s,r,o,t.info,a,l),d=!0);return d}function O(e,t){if(t){let n=t.name;return n==e||!(!t.structured||!(0,i.jg)(n,e))||!(!t.wildcard||!(0,i.SG)(n,e))}return!0}function T(e,t,n,s,r){let i="string"==typeof r.method?e[r.method]:r.method,o=r.property;i?i.call(e,e.__data[o],s[o]):r.dynamicFn||console.warn("observer method `"+r.method+"` not defined")}function A(e,t,n){let s=(0,i.Jz)(t);if(s!==t){return N(e,(0,o.n)(s)+"-changed",n[t],t),!0}return!1}function N(e,t,n,r){let i={value:n,queueProperty:!0};r&&(i.path=r),(0,s.r)(e).dispatchEvent(new CustomEvent(t,{detail:i}))}function I(e,t,n,s,r,o){let a=(o?(0,i.Jz)(t):t)!=t?t:null,l=a?(0,i.U2)(e,a):e.__data[t];a&&void 0===l&&(l=n[t]),N(e,r.eventName,l,a)}function k(e,t,n,s,r){let i=e.__data[t];g.v1&&(i=(0,g.v1)(i,r.attrName,"attribute",e)),e._propertyToAttribute(t,r.attrName,i)}function M(e,t,n,s){let r=e[P.COMPUTE];if(r)if(g.ls){b++;const i=function(e){let t=e.constructor.__orderedComputedDeps;if(!t){t=new Map;const n=e[P.COMPUTE];let s,{counts:r,ready:i,total:o}=function(e){const t=e.__computeInfo,n={},s=e[P.COMPUTE],r=[];let i=0;for(let e in t){const s=t[e];i+=n[e]=s.args.filter((e=>!e.literal)).length+(s.dynamicFn?1:0)}for(let e in s)t[e]||r.push(e);return{counts:n,ready:r,total:i}}(e);for(;s=i.shift();){t.set(s,t.size);const e=n[s];e&&e.forEach((e=>{const t=e.info.methodInfo;--o,0==--r[t]&&i.push(t)}))}if(0!==o){const t=e;console.warn(`Computed graph for ${t.localName} incomplete; circular?`)}e.constructor.__orderedComputedDeps=t}return t}(e),o=[];for(let e in t)R(e,r,o,i,s);let a;for(;a=o.shift();)L(e,"",t,n,a)&&R(a.methodInfo,r,o,i,s);Object.assign(n,e.__dataOld),Object.assign(t,e.__dataPending),e.__dataPending=null}else{let i=t;for(;S(e,r,i,n,s);)Object.assign(n,e.__dataOld),Object.assign(t,e.__dataPending),i=e.__dataPending,e.__dataPending=null}}const D=(e,t,n)=>{let s=0,r=t.length-1,i=-1;for(;s<=r;){const o=s+r>>1,a=n.get(t[o].methodInfo)-n.get(e.methodInfo);if(a<0)s=o+1;else{if(!(a>0)){i=o;break}r=o-1}}i<0&&(i=r+1),t.splice(i,0,e)},R=(e,t,n,s,r)=>{const o=t[r?(0,i.Jz)(e):e];if(o)for(let t=0;t<o.length;t++){const i=o[t];i.info.lastRun===b||r&&!O(e,i.trigger)||(i.info.lastRun=b,D(i.info,n,s))}};function L(e,t,n,s,r){let i=$(e,t,n,s,r);if(i===w)return!1;let o=r.methodInfo;return e.__dataHasAccessor&&e.__dataHasAccessor[o]?e._setPendingProperty(o,i,!0):(e[o]=i,!1)}function F(e,t,n,s,r,i,a){n.bindings=n.bindings||[];let l={kind:s,target:r,parts:i,literal:a,isCompound:1!==i.length};if(n.bindings.push(l),function(e){return Boolean(e.target)&&"attribute"!=e.kind&&"text"!=e.kind&&!e.isCompound&&"{"===e.parts[0].mode}(l)){let{event:e,negate:t}=l.parts[0];l.listenerEvent=e||(0,o.n)(r)+"-changed",l.listenerNegate=t}let d=t.nodeInfoList.length;for(let n=0;n<l.parts.length;n++){let s=l.parts[n];s.compoundIndex=n,H(e,t,l,s,d)}}function H(e,t,n,s,r){if(!s.literal)if("attribute"===n.kind&&"-"===n.target[0])console.warn("Cannot set attribute "+n.target+' because "-" is not a valid attribute starting character');else{let i=s.dependencies,o={index:r,binding:n,part:s,evaluator:e};for(let n=0;n<i.length;n++){let s=i[n];"string"==typeof s&&(s=X(s),s.wildcard=!0),e._addTemplatePropertyEffect(t,s.rootProperty,{fn:z,info:o,trigger:s})}}}function z(e,t,n,s,r,o,a){let l=a[r.index],d=r.binding,c=r.part;if(o&&c.source&&t.length>c.source.length&&"property"==d.kind&&!d.isCompound&&l.__isPropertyEffectsClient&&l.__dataHasAccessor&&l.__dataHasAccessor[d.target]){let s=n[t];t=(0,i.Iu)(c.source,d.target,t),l._setPendingPropertyOrPath(t,s,!1,!0)&&e._enqueueClient(l)}else{let i=r.evaluator._evaluateBinding(e,c,t,n,s,o);i!==w&&function(e,t,n,s,r){r=function(e,t,n,s){if(n.isCompound){let r=e.__dataCompoundStorage[n.target];r[s.compoundIndex]=t,t=r.join("")}"attribute"!==n.kind&&("textContent"!==n.target&&("value"!==n.target||"input"!==e.localName&&"textarea"!==e.localName)||(t=null==t?"":t));return t}(t,r,n,s),g.v1&&(r=(0,g.v1)(r,n.target,n.kind,t));if("attribute"==n.kind)e._valueToNodeAttribute(t,r,n.target);else{let s=n.target;t.__isPropertyEffectsClient&&t.__dataHasAccessor&&t.__dataHasAccessor[s]?t[P.READ_ONLY]&&t[P.READ_ONLY][s]||t._setPendingProperty(s,r)&&e._enqueueClient(t):e._setUnmanagedPropertyToNode(t,s,r)}}(e,l,d,c,i)}}function j(e,t){if(t.isCompound){let n=e.__dataCompoundStorage||(e.__dataCompoundStorage={}),r=t.parts,i=new Array(r.length);for(let e=0;e<r.length;e++)i[e]=r[e].literal;let o=t.target;n[o]=i,t.literal&&"property"==t.kind&&("className"===o&&(e=(0,s.r)(e)),e[o]=t.literal)}}function B(e,t,n){if(n.listenerEvent){let s=n.parts[0];e.addEventListener(n.listenerEvent,(function(e){!function(e,t,n,s,r){let o,a=e.detail,l=a&&a.path;l?(s=(0,i.Iu)(n,s,l),o=a&&a.value):o=e.currentTarget[n],o=r?!o:o,t[P.READ_ONLY]&&t[P.READ_ONLY][s]||!t._setPendingPropertyOrPath(s,o,!0,Boolean(l))||a&&a.queueProperty||t._invalidateProperties()}(e,t,n.target,s.source,s.negate)}))}}function U(e,t,n,s,r,i){i=t.static||i&&("object"!=typeof i||i[t.methodName]);let o={methodName:t.methodName,args:t.args,methodInfo:r,dynamicFn:i};for(let r,i=0;i<t.args.length&&(r=t.args[i]);i++)r.literal||e._addPropertyEffect(r.rootProperty,n,{fn:s,info:o,trigger:r});return i&&e._addPropertyEffect(t.methodName,n,{fn:s,info:o}),o}function $(e,t,n,s,r){let i=e._methodHost||e,o=i[r.methodName];if(o){let s=e._marshalArgs(r.args,t,n);return s===w?w:o.apply(i,s)}r.dynamicFn||console.warn("method `"+r.methodName+"` not defined")}const Y=[],q=new RegExp("(\\[\\[|{{)\\s*(?:(!)\\s*)?((?:[a-zA-Z_$][\\w.:$\\-*]*)\\s*(?:\\(\\s*(?:(?:(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*)(?:,\\s*(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*))*)?)\\)\\s*)?)(?:]]|}})","g");function J(e){let t="";for(let n=0;n<e.length;n++){t+=e[n].literal||""}return t}function V(e){let t=e.match(/([^\s]+?)\(([\s\S]*)\)/);if(t){let e={methodName:t[1],static:!0,args:Y};if(t[2].trim()){return function(e,t){return t.args=e.map((function(e){let n=X(e);return n.literal||(t.static=!1),n}),this),t}(t[2].replace(/\\,/g,"&comma;").split(","),e)}return e}return null}function X(e){let t=e.trim().replace(/&comma;/g,",").replace(/\\(.)/g,"$1"),n={name:t,value:"",literal:!1},s=t[0];switch("-"===s&&(s=t[1]),s>="0"&&s<="9"&&(s="#"),s){case"'":case'"':n.value=t.slice(1,-1),n.literal=!0;break;case"#":n.value=Number(t),n.literal=!0}return n.literal||(n.rootProperty=(0,i.Jz)(t),n.structured=(0,i.AZ)(t),n.structured&&(n.wildcard=".*"==t.slice(-2),n.wildcard&&(n.name=t.slice(0,-2)))),n}function W(e,t,n){let s=(0,i.U2)(e,n);return void 0===s&&(s=t[n]),s}function G(e,t,n,s){const r={indexSplices:s};g.HY&&!e._overrideLegacyUndefined&&(t.splices=r),e.notifyPath(n+".splices",r),e.notifyPath(n+".length",t.length),g.HY&&!e._overrideLegacyUndefined&&(r.indexSplices=[])}function Z(e,t,n,s,r,i){G(e,t,n,[{index:s,addedCount:r,removed:i,object:t,type:"splice"}])}const K=(0,r.o)((e=>{const t=y((0,a.Q)(e));return class extends t{constructor(){super(),this.__isPropertyEffectsClient=!0,this.__dataClientsReady,this.__dataPendingClients,this.__dataToNotify,this.__dataLinkedPaths,this.__dataHasPaths,this.__dataCompoundStorage,this.__dataHost,this.__dataTemp,this.__dataClientsInitialized,this.__data,this.__dataPending,this.__dataOld,this.__computeEffects,this.__computeInfo,this.__reflectEffects,this.__notifyEffects,this.__propagateEffects,this.__observeEffects,this.__readOnly,this.__templateInfo,this._overrideLegacyUndefined}get PROPERTY_EFFECT_TYPES(){return P}_initializeProperties(){super._initializeProperties(),this._registerHost(),this.__dataClientsReady=!1,this.__dataPendingClients=null,this.__dataToNotify=null,this.__dataLinkedPaths=null,this.__dataHasPaths=!1,this.__dataCompoundStorage=this.__dataCompoundStorage||null,this.__dataHost=this.__dataHost||null,this.__dataTemp={},this.__dataClientsInitialized=!1}_registerHost(){if(Q.length){let e=Q[Q.length-1];e._enqueueClient(this),this.__dataHost=e}}_initializeProtoProperties(e){this.__data=Object.create(e),this.__dataPending=Object.create(e),this.__dataOld={}}_initializeInstanceProperties(e){let t=this[P.READ_ONLY];for(let n in e)t&&t[n]||(this.__dataPending=this.__dataPending||{},this.__dataOld=this.__dataOld||{},this.__data[n]=this.__dataPending[n]=e[n])}_addPropertyEffect(e,t,n){this._createPropertyAccessor(e,t==P.READ_ONLY);let s=x(this,t,!0)[e];s||(s=this[t][e]=[]),s.push(n)}_removePropertyEffect(e,t,n){let s=x(this,t,!0)[e],r=s.indexOf(n);r>=0&&s.splice(r,1)}_hasPropertyEffect(e,t){let n=this[t];return Boolean(n&&n[e])}_hasReadOnlyEffect(e){return this._hasPropertyEffect(e,P.READ_ONLY)}_hasNotifyEffect(e){return this._hasPropertyEffect(e,P.NOTIFY)}_hasReflectEffect(e){return this._hasPropertyEffect(e,P.REFLECT)}_hasComputedEffect(e){return this._hasPropertyEffect(e,P.COMPUTE)}_setPendingPropertyOrPath(e,t,n,s){if(s||(0,i.Jz)(Array.isArray(e)?e[0]:e)!==e){if(!s){let n=(0,i.U2)(this,e);if(!(e=(0,i.t8)(this,e,t))||!super._shouldPropertyChange(e,t,n))return!1}if(this.__dataHasPaths=!0,this._setPendingProperty(e,t,n))return function(e,t,n){let s=e.__dataLinkedPaths;if(s){let r;for(let o in s){let a=s[o];(0,i.SG)(o,t)?(r=(0,i.Iu)(o,a,t),e._setPendingPropertyOrPath(r,n,!0,!0)):(0,i.SG)(a,t)&&(r=(0,i.Iu)(a,o,t),e._setPendingPropertyOrPath(r,n,!0,!0))}}}(this,e,t),!0}else{if(this.__dataHasAccessor&&this.__dataHasAccessor[e])return this._setPendingProperty(e,t,n);this[e]=t}return!1}_setUnmanagedPropertyToNode(e,t,n){n===e[t]&&"object"!=typeof n||("className"===t&&(e=(0,s.r)(e)),e[t]=n)}_setPendingProperty(e,t,n){let s=this.__dataHasPaths&&(0,i.AZ)(e),r=s?this.__dataTemp:this.__data;return!!this._shouldPropertyChange(e,t,r[e])&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),e in this.__dataOld||(this.__dataOld[e]=this.__data[e]),s?this.__dataTemp[e]=t:this.__data[e]=t,this.__dataPending[e]=t,(s||this[P.NOTIFY]&&this[P.NOTIFY][e])&&(this.__dataToNotify=this.__dataToNotify||{},this.__dataToNotify[e]=n),!0)}_setProperty(e,t){this._setPendingProperty(e,t,!0)&&this._invalidateProperties()}_invalidateProperties(){this.__dataReady&&this._flushProperties()}_enqueueClient(e){this.__dataPendingClients=this.__dataPendingClients||[],e!==this&&this.__dataPendingClients.push(e)}_flushClients(){this.__dataClientsReady?this.__enableOrFlushClients():(this.__dataClientsReady=!0,this._readyClients(),this.__dataReady=!0)}__enableOrFlushClients(){let e=this.__dataPendingClients;if(e){this.__dataPendingClients=null;for(let t=0;t<e.length;t++){let n=e[t];n.__dataEnabled?n.__dataPending&&n._flushProperties():n._enableProperties()}}}_readyClients(){this.__enableOrFlushClients()}setProperties(e,t){for(let n in e)!t&&this[P.READ_ONLY]&&this[P.READ_ONLY][n]||this._setPendingPropertyOrPath(n,e[n],!0);this._invalidateProperties()}ready(){this._flushProperties(),this.__dataClientsReady||this._flushClients(),this.__dataPending&&this._flushProperties()}_propertiesChanged(e,t,n){let s,r=this.__dataHasPaths;this.__dataHasPaths=!1,M(this,t,n,r),s=this.__dataToNotify,this.__dataToNotify=null,this._propagatePropertyChanges(t,n,r),this._flushClients(),S(this,this[P.REFLECT],t,n,r),S(this,this[P.OBSERVE],t,n,r),s&&function(e,t,n,s,r){let i,o,a=e[P.NOTIFY],l=b++;for(let o in t)t[o]&&(a&&E(e,a,l,o,n,s,r)||r&&A(e,o,n))&&(i=!0);i&&(o=e.__dataHost)&&o._invalidateProperties&&o._invalidateProperties()}(this,s,t,n,r),1==this.__dataCounter&&(this.__dataTemp={})}_propagatePropertyChanges(e,t,n){this[P.PROPAGATE]&&S(this,this[P.PROPAGATE],e,t,n),this.__templateInfo&&this._runEffectsForTemplate(this.__templateInfo,e,t,n)}_runEffectsForTemplate(e,t,n,s){const r=(t,s)=>{S(this,e.propertyEffects,t,n,s,e.nodeList);for(let r=e.firstChild;r;r=r.nextSibling)this._runEffectsForTemplate(r,t,n,s)};e.runEffects?e.runEffects(r,t,s):r(t,s)}linkPaths(e,t){e=(0,i.Fv)(e),t=(0,i.Fv)(t),this.__dataLinkedPaths=this.__dataLinkedPaths||{},this.__dataLinkedPaths[e]=t}unlinkPaths(e){e=(0,i.Fv)(e),this.__dataLinkedPaths&&delete this.__dataLinkedPaths[e]}notifySplices(e,t){let n={path:""};G(this,(0,i.U2)(this,e,n),n.path,t)}get(e,t){return(0,i.U2)(t||this,e)}set(e,t,n){n?(0,i.t8)(n,e,t):this[P.READ_ONLY]&&this[P.READ_ONLY][e]||this._setPendingPropertyOrPath(e,t,!0)&&this._invalidateProperties()}push(e,...t){let n={path:""},s=(0,i.U2)(this,e,n),r=s.length,o=s.push(...t);return t.length&&Z(this,s,n.path,r,t.length,[]),o}pop(e){let t={path:""},n=(0,i.U2)(this,e,t),s=Boolean(n.length),r=n.pop();return s&&Z(this,n,t.path,n.length,0,[r]),r}splice(e,t,n,...s){let r,o={path:""},a=(0,i.U2)(this,e,o);return t<0?t=a.length-Math.floor(-t):t&&(t=Math.floor(t)),r=2===arguments.length?a.splice(t):a.splice(t,n,...s),(s.length||r.length)&&Z(this,a,o.path,t,s.length,r),r}shift(e){let t={path:""},n=(0,i.U2)(this,e,t),s=Boolean(n.length),r=n.shift();return s&&Z(this,n,t.path,0,0,[r]),r}unshift(e,...t){let n={path:""},s=(0,i.U2)(this,e,n),r=s.unshift(...t);return t.length&&Z(this,s,n.path,0,t.length,[]),r}notifyPath(e,t){let n;if(1==arguments.length){let s={path:""};t=(0,i.U2)(this,e,s),n=s.path}else n=Array.isArray(e)?(0,i.Fv)(e):e;this._setPendingPropertyOrPath(n,t,!0,!0)&&this._invalidateProperties()}_createReadOnlyProperty(e,t){var n;this._addPropertyEffect(e,P.READ_ONLY),t&&(this["_set"+(n=e,n[0].toUpperCase()+n.substring(1))]=function(t){this._setProperty(e,t)})}_createPropertyObserver(e,t,n){let s={property:e,method:t,dynamicFn:Boolean(n)};this._addPropertyEffect(e,P.OBSERVE,{fn:T,info:s,trigger:{name:e}}),n&&this._addPropertyEffect(t,P.OBSERVE,{fn:T,info:s,trigger:{name:t}})}_createMethodObserver(e,t){let n=V(e);if(!n)throw new Error("Malformed observer expression '"+e+"'");U(this,n,P.OBSERVE,$,null,t)}_createNotifyingProperty(e){this._addPropertyEffect(e,P.NOTIFY,{fn:I,info:{eventName:(0,o.n)(e)+"-changed",property:e}})}_createReflectedProperty(e){let t=this.constructor.attributeNameForProperty(e);"-"===t[0]?console.warn("Property "+e+" cannot be reflected to attribute "+t+' because "-" is not a valid starting attribute name. Use a lowercase first letter for the property instead.'):this._addPropertyEffect(e,P.REFLECT,{fn:k,info:{attrName:t}})}_createComputedProperty(e,t,n){let s=V(t);if(!s)throw new Error("Malformed computed expression '"+t+"'");const r=U(this,s,P.COMPUTE,L,e,n);x(this,C)[e]=r}_marshalArgs(e,t,n){const s=this.__data,r=[];for(let o=0,a=e.length;o<a;o++){let{name:a,structured:l,wildcard:d,value:c,literal:h}=e[o];if(!h)if(d){const e=(0,i.SG)(a,t),r=W(s,n,e?t:a);c={path:e?t:a,value:r,base:e?(0,i.U2)(s,a):r}}else c=l?W(s,n,a):s[a];if(g.HY&&!this._overrideLegacyUndefined&&void 0===c&&e.length>1)return w;r[o]=c}return r}static addPropertyEffect(e,t,n){this.prototype._addPropertyEffect(e,t,n)}static createPropertyObserver(e,t,n){this.prototype._createPropertyObserver(e,t,n)}static createMethodObserver(e,t){this.prototype._createMethodObserver(e,t)}static createNotifyingProperty(e){this.prototype._createNotifyingProperty(e)}static createReadOnlyProperty(e,t){this.prototype._createReadOnlyProperty(e,t)}static createReflectedProperty(e){this.prototype._createReflectedProperty(e)}static createComputedProperty(e,t,n){this.prototype._createComputedProperty(e,t,n)}static bindTemplate(e){return this.prototype._bindTemplate(e)}_bindTemplate(e,t){let n=this.constructor._parseTemplate(e),s=this.__preBoundTemplateInfo==n;if(!s)for(let e in n.propertyEffects)this._createPropertyAccessor(e);if(t)if(n=Object.create(n),n.wasPreBound=s,this.__templateInfo){const t=e._parentTemplateInfo||this.__templateInfo,s=t.lastChild;n.parent=t,t.lastChild=n,n.previousSibling=s,s?s.nextSibling=n:t.firstChild=n}else this.__templateInfo=n;else this.__preBoundTemplateInfo=n;return n}static _addTemplatePropertyEffect(e,t,n){(e.hostProps=e.hostProps||{})[t]=!0;let s=e.propertyEffects=e.propertyEffects||{};(s[t]=s[t]||[]).push(n)}_stampTemplate(e,t){t=t||this._bindTemplate(e,!0),Q.push(this);let n=super._stampTemplate(e,t);if(Q.pop(),t.nodeList=n.nodeList,!t.wasPreBound){let e=t.childNodes=[];for(let t=n.firstChild;t;t=t.nextSibling)e.push(t)}return n.templateInfo=t,function(e,t){let{nodeList:n,nodeInfoList:s}=t;if(s.length)for(let t=0;t<s.length;t++){let r=s[t],i=n[t],o=r.bindings;if(o)for(let t=0;t<o.length;t++){let n=o[t];j(i,n),B(i,e,n)}i.__dataHost=e}}(this,t),this.__dataClientsReady&&(this._runEffectsForTemplate(t,this.__data,null,!1),this._flushClients()),n}_removeBoundDom(e){const t=e.templateInfo,{previousSibling:n,nextSibling:r,parent:i}=t;n?n.nextSibling=r:i&&(i.firstChild=r),r?r.previousSibling=n:i&&(i.lastChild=n),t.nextSibling=t.previousSibling=null;let o=t.childNodes;for(let e=0;e<o.length;e++){let t=o[e];(0,s.r)((0,s.r)(t).parentNode).removeChild(t)}}static _parseTemplateNode(e,n,s){let r=t._parseTemplateNode.call(this,e,n,s);if(e.nodeType===Node.TEXT_NODE){let t=this._parseBindings(e.textContent,n);t&&(e.textContent=J(t)||" ",F(this,n,s,"text","textContent",t),r=!0)}return r}static _parseTemplateNodeAttribute(e,n,s,r,i){let a=this._parseBindings(i,n);if(a){let t=r,i="property";v.test(r)?i="attribute":"$"==r[r.length-1]&&(r=r.slice(0,-1),i="attribute");let l=J(a);return l&&"attribute"==i&&("class"==r&&e.hasAttribute("class")&&(l+=" "+e.getAttribute(r)),e.setAttribute(r,l)),"attribute"==i&&"disable-upgrade$"==t&&e.setAttribute(r,""),"input"===e.localName&&"value"===t&&e.setAttribute(t,""),e.removeAttribute(t),"property"===i&&(r=(0,o.z)(r)),F(this,n,s,i,r,a,l),!0}return t._parseTemplateNodeAttribute.call(this,e,n,s,r,i)}static _parseTemplateNestedTemplate(e,n,s){let r=t._parseTemplateNestedTemplate.call(this,e,n,s);const i=e.parentNode,o=s.templateInfo,a="dom-if"===i.localName,l="dom-repeat"===i.localName;g.gx&&(a||l)&&(i.removeChild(e),(s=s.parentInfo).templateInfo=o,s.noted=!0,r=!1);let d=o.hostProps;if(g.ew&&a)d&&(n.hostProps=Object.assign(n.hostProps||{},d),g.gx||(s.parentInfo.noted=!0));else{let e="{";for(let t in d){F(this,n,s,"property","_host_"+t,[{mode:e,source:t,dependencies:[t],hostProp:!0}])}}return r}static _parseBindings(e,t){let n,s=[],r=0;for(;null!==(n=q.exec(e));){n.index>r&&s.push({literal:e.slice(r,n.index)});let i=n[1][0],o=Boolean(n[2]),a=n[3].trim(),l=!1,d="",c=-1;"{"==i&&(c=a.indexOf("::"))>0&&(d=a.substring(c+2),a=a.substring(0,c),l=!0);let h=V(a),p=[];if(h){let{args:e,methodName:n}=h;for(let t=0;t<e.length;t++){let n=e[t];n.literal||p.push(n)}let s=t.dynamicFns;(s&&s[n]||h.static)&&(p.push(n),h.dynamicFn=!0)}else p.push(a);s.push({source:a,mode:i,negate:o,customEvent:l,signature:h,dependencies:p,event:d}),r=q.lastIndex}if(r&&r<e.length){let t=e.substring(r);t&&s.push({literal:t})}return s.length?s:null}static _evaluateBinding(e,t,n,s,r,o){let a;return a=t.signature?$(e,n,s,0,t.signature):n!=t.source?(0,i.U2)(e,t.source):o&&(0,i.AZ)(n)?(0,i.U2)(e,n):e.__data[n],t.negate&&(a=!a),a}}})),Q=[]},4507:(e,t,n)=>{n.d(t,{c:()=>i});n(56646);function s(e,t,n){return{index:e,removed:t,addedCount:n}}function r(e,t,n,r,i,a){let l,d=0,c=0,h=Math.min(n-t,a-i);if(0==t&&0==i&&(d=function(e,t,n){for(let s=0;s<n;s++)if(!o(e[s],t[s]))return s;return n}(e,r,h)),n==e.length&&a==r.length&&(c=function(e,t,n){let s=e.length,r=t.length,i=0;for(;i<n&&o(e[--s],t[--r]);)i++;return i}(e,r,h-d)),i+=d,a-=c,(n-=c)-(t+=d)==0&&a-i==0)return[];if(t==n){for(l=s(t,[],0);i<a;)l.removed.push(r[i++]);return[l]}if(i==a)return[s(t,[],n-t)];let p=function(e){let t=e.length-1,n=e[0].length-1,s=e[t][n],r=[];for(;t>0||n>0;){if(0==t){r.push(2),n--;continue}if(0==n){r.push(3),t--;continue}let i,o=e[t-1][n-1],a=e[t-1][n],l=e[t][n-1];i=a<l?a<o?a:o:l<o?l:o,i==o?(o==s?r.push(0):(r.push(1),s=o),t--,n--):i==a?(r.push(3),t--,s=a):(r.push(2),n--,s=l)}return r.reverse(),r}(function(e,t,n,s,r,i){let a=i-r+1,l=n-t+1,d=new Array(a);for(let e=0;e<a;e++)d[e]=new Array(l),d[e][0]=e;for(let e=0;e<l;e++)d[0][e]=e;for(let n=1;n<a;n++)for(let i=1;i<l;i++)if(o(e[t+i-1],s[r+n-1]))d[n][i]=d[n-1][i-1];else{let e=d[n-1][i]+1,t=d[n][i-1]+1;d[n][i]=e<t?e:t}return d}(e,t,n,r,i,a));l=void 0;let u=[],_=t,f=i;for(let e=0;e<p.length;e++)switch(p[e]){case 0:l&&(u.push(l),l=void 0),_++,f++;break;case 1:l||(l=s(_,[],0)),l.addedCount++,_++,l.removed.push(r[f]),f++;break;case 2:l||(l=s(_,[],0)),l.addedCount++,_++;break;case 3:l||(l=s(_,[],0)),l.removed.push(r[f]),f++}return l&&u.push(l),u}function i(e,t){return r(e,0,e.length,t,0,t.length)}function o(e,t){return e===t}},21683:(e,t,n)=>{n.d(t,{Wc:()=>d,YA:()=>c});n(56646);let s=0,r=0,i=[],o=0,a=!1,l=document.createTextNode("");new window.MutationObserver((function(){a=!1;const e=i.length;for(let t=0;t<e;t++){let e=i[t];if(e)try{e()}catch(e){setTimeout((()=>{throw e}))}}i.splice(0,e),r+=e})).observe(l,{characterData:!0});const d={after:e=>({run:t=>window.setTimeout(t,e),cancel(e){window.clearTimeout(e)}}),run:(e,t)=>window.setTimeout(e,t),cancel(e){window.clearTimeout(e)}},c={run:e=>(a||(a=!0,l.textContent=o++),i.push(e),s++),cancel(e){const t=e-r;if(t>=0){if(!i[t])throw new Error("invalid async handle: "+e);i[t]=null}}}},56646:()=>{window.JSCompiler_renameProperty=function(e,t){return e}},67130:(e,t,n)=>{n.d(t,{z:()=>o,n:()=>a});n(56646);const s={},r=/-[a-z]/g,i=/([A-Z])/g;function o(e){return s[e]||(s[e]=e.indexOf("-")<0?e:e.replace(r,(e=>e[1].toUpperCase())))}function a(e){return s[e]||(s[e]=e.replace(i,"-$1").toLowerCase())}},78956:(e,t,n)=>{n.d(t,{dx:()=>s,Ex:()=>i,Jk:()=>o});n(56646),n(76389),n(21683);class s{constructor(){this._asyncModule=null,this._callback=null,this._timer=null}setConfig(e,t){this._asyncModule=e,this._callback=t,this._timer=this._asyncModule.run((()=>{this._timer=null,r.delete(this),this._callback()}))}cancel(){this.isActive()&&(this._cancelAsync(),r.delete(this))}_cancelAsync(){this.isActive()&&(this._asyncModule.cancel(this._timer),this._timer=null)}flush(){this.isActive()&&(this.cancel(),this._callback())}isActive(){return null!=this._timer}static debounce(e,t,n){return e instanceof s?e._cancelAsync():e=new s,e.setConfig(t,n),e}}let r=new Set;const i=function(e){r.add(e)},o=function(){const e=Boolean(r.size);return r.forEach((e=>{try{e.flush()}catch(e){setTimeout((()=>{throw e}))}})),e}},20723:(e,t,n)=>{n.d(t,{o:()=>a});n(56646);var s=n(4507),r=n(21683),i=n(62276);function o(e){return"slot"===e.localName}let a=class{static getFlattenedNodes(e){const t=(0,i.r)(e);return o(e)?(e=e,t.assignedNodes({flatten:!0})):Array.from(t.childNodes).map((e=>o(e)?(e=e,(0,i.r)(e).assignedNodes({flatten:!0})):[e])).reduce(((e,t)=>e.concat(t)),[])}constructor(e,t){this._shadyChildrenObserver=null,this._nativeChildrenObserver=null,this._connected=!1,this._target=e,this.callback=t,this._effectiveNodes=[],this._observer=null,this._scheduled=!1,this._boundSchedule=()=>{this._schedule()},this.connect(),this._schedule()}connect(){o(this._target)?this._listenSlots([this._target]):(0,i.r)(this._target).children&&(this._listenSlots((0,i.r)(this._target).children),window.ShadyDOM?this._shadyChildrenObserver=window.ShadyDOM.observeChildren(this._target,(e=>{this._processMutations(e)})):(this._nativeChildrenObserver=new MutationObserver((e=>{this._processMutations(e)})),this._nativeChildrenObserver.observe(this._target,{childList:!0}))),this._connected=!0}disconnect(){o(this._target)?this._unlistenSlots([this._target]):(0,i.r)(this._target).children&&(this._unlistenSlots((0,i.r)(this._target).children),window.ShadyDOM&&this._shadyChildrenObserver?(window.ShadyDOM.unobserveChildren(this._shadyChildrenObserver),this._shadyChildrenObserver=null):this._nativeChildrenObserver&&(this._nativeChildrenObserver.disconnect(),this._nativeChildrenObserver=null)),this._connected=!1}_schedule(){this._scheduled||(this._scheduled=!0,r.YA.run((()=>this.flush())))}_processMutations(e){this._processSlotMutations(e),this.flush()}_processSlotMutations(e){if(e)for(let t=0;t<e.length;t++){let n=e[t];n.addedNodes&&this._listenSlots(n.addedNodes),n.removedNodes&&this._unlistenSlots(n.removedNodes)}}flush(){if(!this._connected)return!1;window.ShadyDOM&&ShadyDOM.flush(),this._nativeChildrenObserver?this._processSlotMutations(this._nativeChildrenObserver.takeRecords()):this._shadyChildrenObserver&&this._processSlotMutations(this._shadyChildrenObserver.takeRecords()),this._scheduled=!1;let e={target:this._target,addedNodes:[],removedNodes:[]},t=this.constructor.getFlattenedNodes(this._target),n=(0,s.c)(t,this._effectiveNodes);for(let t,s=0;s<n.length&&(t=n[s]);s++)for(let n,s=0;s<t.removed.length&&(n=t.removed[s]);s++)e.removedNodes.push(n);for(let s,r=0;r<n.length&&(s=n[r]);r++)for(let n=s.index;n<s.index+s.addedCount;n++)e.addedNodes.push(t[n]);this._effectiveNodes=t;let r=!1;return(e.addedNodes.length||e.removedNodes.length)&&(r=!0,this.callback.call(this._target,e)),r}_listenSlots(e){for(let t=0;t<e.length;t++){let n=e[t];o(n)&&n.addEventListener("slotchange",this._boundSchedule)}}_unlistenSlots(e){for(let t=0;t<e.length;t++){let n=e[t];o(n)&&n.removeEventListener("slotchange",this._boundSchedule)}}}},93252:(e,t,n)=>{n.d(t,{E:()=>s.Ex,y:()=>r});n(56646);var s=n(78956);const r=function(){let e,t;do{e=window.ShadyDOM&&ShadyDOM.flush(),window.ShadyCSS&&window.ShadyCSS.ScopingShim&&window.ShadyCSS.ScopingShim.flush(),t=(0,s.Jk)()}while(e||t)}},81668:(e,t,n)=>{n.d(t,{NH:()=>M,ys:()=>D,BP:()=>L});n(56646);var s=n(21683),r=n(78956),i=n(74460),o=n(62276);let a="string"==typeof document.head.style.touchAction,l="__polymerGestures",d="__polymerGesturesHandled",c="__polymerGesturesTouchAction",h=["mousedown","mousemove","mouseup","click"],p=[0,1,4,2],u=function(){try{return 1===new MouseEvent("test",{buttons:1}).buttons}catch(e){return!1}}();function _(e){return h.indexOf(e)>-1}let f=!1;function m(e){if(!_(e)&&"touchend"!==e)return a&&f&&i.f6?{passive:!0}:void 0}!function(){try{let e=Object.defineProperty({},"passive",{get(){f=!0}});window.addEventListener("test",null,e),window.removeEventListener("test",null,e)}catch(e){}}();let y=navigator.userAgent.match(/iP(?:[oa]d|hone)|Android/);const g=[],b={button:!0,input:!0,keygen:!0,meter:!0,output:!0,textarea:!0,progress:!0,select:!0},w={button:!0,command:!0,fieldset:!0,input:!0,keygen:!0,optgroup:!0,option:!0,select:!0,textarea:!0};function P(e){let t=Array.prototype.slice.call(e.labels||[]);if(!t.length){t=[];let n=e.getRootNode();if(e.id){let s=n.querySelectorAll(`label[for = ${e.id}]`);for(let e=0;e<s.length;e++)t.push(s[e])}}return t}let C=function(e){let t=e.sourceCapabilities;var n;if((!t||t.firesTouchEvents)&&(e[d]={skip:!0},"click"===e.type)){let t=!1,s=T(e);for(let e=0;e<s.length;e++){if(s[e].nodeType===Node.ELEMENT_NODE)if("label"===s[e].localName)g.push(s[e]);else if(n=s[e],b[n.localName]){let n=P(s[e]);for(let e=0;e<n.length;e++)t=t||g.indexOf(n[e])>-1}if(s[e]===S.mouse.target)return}if(t)return;e.preventDefault(),e.stopPropagation()}};function v(e){let t=y?["click"]:h;for(let n,s=0;s<t.length;s++)n=t[s],e?(g.length=0,document.addEventListener(n,C,!0)):document.removeEventListener(n,C,!0)}function x(e){let t=e.type;if(!_(t))return!1;if("mousemove"===t){let t=void 0===e.buttons?1:e.buttons;return e instanceof window.MouseEvent&&!u&&(t=p[e.which]||0),Boolean(1&t)}return 0===(void 0===e.button?0:e.button)}let S={mouse:{target:null,mouseIgnoreJob:null},touch:{x:0,y:0,id:-1,scrollDecided:!1}};function E(e,t,n){e.movefn=t,e.upfn=n,document.addEventListener("mousemove",t),document.addEventListener("mouseup",n)}function O(e){document.removeEventListener("mousemove",e.movefn),document.removeEventListener("mouseup",e.upfn),e.movefn=null,e.upfn=null}i.z2&&document.addEventListener("touchend",(function(e){if(!i.z2)return;S.mouse.mouseIgnoreJob||v(!0),S.mouse.target=T(e)[0],S.mouse.mouseIgnoreJob=r.dx.debounce(S.mouse.mouseIgnoreJob,s.Wc.after(2500),(function(){v(),S.mouse.target=null,S.mouse.mouseIgnoreJob=null}))}),!!f&&{passive:!0});const T=window.ShadyDOM&&window.ShadyDOM.noPatch?window.ShadyDOM.composedPath:e=>e.composedPath&&e.composedPath()||[],A={},N=[];function I(e){const t=T(e);return t.length>0?t[0]:e.target}function k(e){let t,n=e.type,s=e.currentTarget[l];if(!s)return;let r=s[n];if(r){if(!e[d]&&(e[d]={},"touch"===n.slice(0,5))){let t=(e=e).changedTouches[0];if("touchstart"===n&&1===e.touches.length&&(S.touch.id=t.identifier),S.touch.id!==t.identifier)return;a||"touchstart"!==n&&"touchmove"!==n||function(e){let t=e.changedTouches[0],n=e.type;if("touchstart"===n)S.touch.x=t.clientX,S.touch.y=t.clientY,S.touch.scrollDecided=!1;else if("touchmove"===n){if(S.touch.scrollDecided)return;S.touch.scrollDecided=!0;let n=function(e){let t="auto",n=T(e);for(let e,s=0;s<n.length;s++)if(e=n[s],e[c]){t=e[c];break}return t}(e),s=!1,r=Math.abs(S.touch.x-t.clientX),i=Math.abs(S.touch.y-t.clientY);e.cancelable&&("none"===n?s=!0:"pan-x"===n?s=i>r:"pan-y"===n&&(s=r>i)),s?e.preventDefault():H("track")}}(e)}if(t=e[d],!t.skip){for(let n,s=0;s<N.length;s++)n=N[s],r[n.name]&&!t[n.name]&&n.flow&&n.flow.start.indexOf(e.type)>-1&&n.reset&&n.reset();for(let s,i=0;i<N.length;i++)s=N[i],r[s.name]&&!t[s.name]&&(t[s.name]=!0,s[n](e))}}}function M(e,t,n){return!!A[t]&&(function(e,t,n){let s=A[t],r=s.deps,i=s.name,o=e[l];o||(e[l]=o={});for(let t,n,s=0;s<r.length;s++)t=r[s],y&&_(t)&&"click"!==t||(n=o[t],n||(o[t]=n={_count:0}),0===n._count&&e.addEventListener(t,k,m(t)),n[i]=(n[i]||0)+1,n._count=(n._count||0)+1);e.addEventListener(t,n),s.touchAction&&L(e,s.touchAction)}(e,t,n),!0)}function D(e,t,n){return!!A[t]&&(function(e,t,n){let s=A[t],r=s.deps,i=s.name,o=e[l];if(o)for(let t,n,s=0;s<r.length;s++)t=r[s],n=o[t],n&&n[i]&&(n[i]=(n[i]||1)-1,n._count=(n._count||1)-1,0===n._count&&e.removeEventListener(t,k,m(t)));e.removeEventListener(t,n)}(e,t,n),!0)}function R(e){N.push(e);for(let t=0;t<e.emits.length;t++)A[e.emits[t]]=e}function L(e,t){a&&e instanceof HTMLElement&&s.YA.run((()=>{e.style.touchAction=t})),e[c]=t}function F(e,t,n){let s=new Event(t,{bubbles:!0,cancelable:!0,composed:!0});if(s.detail=n,(0,o.r)(e).dispatchEvent(s),s.defaultPrevented){let e=n.preventer||n.sourceEvent;e&&e.preventDefault&&e.preventDefault()}}function H(e){let t=function(e){for(let t,n=0;n<N.length;n++){t=N[n];for(let n,s=0;s<t.emits.length;s++)if(n=t.emits[s],n===e)return t}return null}(e);t.info&&(t.info.prevent=!0)}function z(e,t,n,s){t&&F(t,e,{x:n.clientX,y:n.clientY,sourceEvent:n,preventer:s,prevent:function(e){return H(e)}})}function j(e,t,n){if(e.prevent)return!1;if(e.started)return!0;let s=Math.abs(e.x-t),r=Math.abs(e.y-n);return s>=5||r>=5}function B(e,t,n){if(!t)return;let s,r=e.moves[e.moves.length-2],i=e.moves[e.moves.length-1],o=i.x-e.x,a=i.y-e.y,l=0;r&&(s=i.x-r.x,l=i.y-r.y),F(t,"track",{state:e.state,x:n.clientX,y:n.clientY,dx:o,dy:a,ddx:s,ddy:l,sourceEvent:n,hover:function(){return function(e,t){let n=document.elementFromPoint(e,t),s=n;for(;s&&s.shadowRoot&&!window.ShadyDOM;){let r=s;if(s=s.shadowRoot.elementFromPoint(e,t),r===s)break;s&&(n=s)}return n}(n.clientX,n.clientY)}})}function U(e,t,n){let s=Math.abs(t.clientX-e.x),r=Math.abs(t.clientY-e.y),i=I(n||t);!i||w[i.localName]&&i.hasAttribute("disabled")||(isNaN(s)||isNaN(r)||s<=25&&r<=25||function(e){if("click"===e.type){if(0===e.detail)return!0;let t=I(e);if(!t.nodeType||t.nodeType!==Node.ELEMENT_NODE)return!0;let n=t.getBoundingClientRect(),s=e.pageX,r=e.pageY;return!(s>=n.left&&s<=n.right&&r>=n.top&&r<=n.bottom)}return!1}(t))&&(e.prevent||F(i,"tap",{x:t.clientX,y:t.clientY,sourceEvent:t,preventer:n}))}R({name:"downup",deps:["mousedown","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["down","up"],info:{movefn:null,upfn:null},reset:function(){O(this.info)},mousedown:function(e){if(!x(e))return;let t=I(e),n=this;E(this.info,(function(e){x(e)||(z("up",t,e),O(n.info))}),(function(e){x(e)&&z("up",t,e),O(n.info)})),z("down",t,e)},touchstart:function(e){z("down",I(e),e.changedTouches[0],e)},touchend:function(e){z("up",I(e),e.changedTouches[0],e)}}),R({name:"track",touchAction:"none",deps:["mousedown","touchstart","touchmove","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["track"],info:{x:0,y:0,state:"start",started:!1,moves:[],addMove:function(e){this.moves.length>2&&this.moves.shift(),this.moves.push(e)},movefn:null,upfn:null,prevent:!1},reset:function(){this.info.state="start",this.info.started=!1,this.info.moves=[],this.info.x=0,this.info.y=0,this.info.prevent=!1,O(this.info)},mousedown:function(e){if(!x(e))return;let t=I(e),n=this,s=function(e){let s=e.clientX,r=e.clientY;j(n.info,s,r)&&(n.info.state=n.info.started?"mouseup"===e.type?"end":"track":"start","start"===n.info.state&&H("tap"),n.info.addMove({x:s,y:r}),x(e)||(n.info.state="end",O(n.info)),t&&B(n.info,t,e),n.info.started=!0)};E(this.info,s,(function(e){n.info.started&&s(e),O(n.info)})),this.info.x=e.clientX,this.info.y=e.clientY},touchstart:function(e){let t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchmove:function(e){let t=I(e),n=e.changedTouches[0],s=n.clientX,r=n.clientY;j(this.info,s,r)&&("start"===this.info.state&&H("tap"),this.info.addMove({x:s,y:r}),B(this.info,t,n),this.info.state="track",this.info.started=!0)},touchend:function(e){let t=I(e),n=e.changedTouches[0];this.info.started&&(this.info.state="end",this.info.addMove({x:n.clientX,y:n.clientY}),B(this.info,t,n))}}),R({name:"tap",deps:["mousedown","click","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["click","touchend"]},emits:["tap"],info:{x:NaN,y:NaN,prevent:!1},reset:function(){this.info.x=NaN,this.info.y=NaN,this.info.prevent=!1},mousedown:function(e){x(e)&&(this.info.x=e.clientX,this.info.y=e.clientY)},click:function(e){x(e)&&U(this.info,e)},touchstart:function(e){const t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchend:function(e){U(this.info,e.changedTouches[0],e)}})},6226:(e,t,n)=>{n.d(t,{N:()=>i});var s=n(74460);let r=!1;function i(){if(s.nL&&!s.my){if(!r){r=!0;const e=document.createElement("style");e.textContent="dom-bind,dom-if,dom-repeat{display:none;}",document.head.appendChild(e)}return!0}return!1}},50856:(e,t,n)=>{n.d(t,{d:()=>i});n(56646);class s{constructor(e){this.value=e.toString()}toString(){return this.value}}function r(e){if(e instanceof s)return e.value;throw new Error(`non-literal value passed to Polymer's htmlLiteral function: ${e}`)}const i=function(e,...t){const n=document.createElement("template");return n.innerHTML=t.reduce(((t,n,i)=>t+function(e){if(e instanceof HTMLTemplateElement)return e.innerHTML;if(e instanceof s)return r(e);throw new Error(`non-template value passed to Polymer's html function: ${e}`)}(n)+e[i+1]),e[0]),n}},76389:(e,t,n)=>{n.d(t,{o:()=>i});n(56646);let s=0;function r(){}r.prototype.__mixinApplications,r.prototype.__mixinSet;const i=function(e){let t=e.__mixinApplications;t||(t=new WeakMap,e.__mixinApplications=t);let n=s++;return function(s){let r=s.__mixinSet;if(r&&r[n])return s;let i=t,o=i.get(s);if(!o){o=e(s),i.set(s,o);let t=Object.create(o.__mixinSet||r||null);t[n]=!0,o.__mixinSet=t}return o}}},4059:(e,t,n)=>{n.d(t,{AZ:()=>s,Jz:()=>r,jg:()=>i,SG:()=>o,Iu:()=>a,wB:()=>l,Fv:()=>d,U2:()=>h,t8:()=>p});n(56646);function s(e){return e.indexOf(".")>=0}function r(e){let t=e.indexOf(".");return-1===t?e:e.slice(0,t)}function i(e,t){return 0===e.indexOf(t+".")}function o(e,t){return 0===t.indexOf(e+".")}function a(e,t,n){return t+n.slice(e.length)}function l(e,t){return e===t||i(e,t)||o(e,t)}function d(e){if(Array.isArray(e)){let t=[];for(let n=0;n<e.length;n++){let s=e[n].toString().split(".");for(let e=0;e<s.length;e++)t.push(s[e])}return t.join(".")}return e}function c(e){return Array.isArray(e)?d(e).split("."):e.toString().split(".")}function h(e,t,n){let s=e,r=c(t);for(let e=0;e<r.length;e++){if(!s)return;s=s[r[e]]}return n&&(n.path=r.join(".")),s}function p(e,t,n){let s=e,r=c(t),i=r[r.length-1];if(r.length>1){for(let e=0;e<r.length-1;e++){if(s=s[r[e]],!s)return}s[i]=n}else s[t]=n;return r.join(".")}},87529:(e,t,n)=>{n(56646)},42687:(e,t,n)=>{n.d(t,{Kk:()=>a,Rq:()=>l,iY:()=>d});n(56646);let s,r,i=/(url\()([^)]*)(\))/g,o=/(^\/[^\/])|(^#)|(^[\w-\d]*:)/;function a(e,t){if(e&&o.test(e))return e;if("//"===e)return e;if(void 0===s){s=!1;try{const e=new URL("b","http://a");e.pathname="c%20d",s="http://a/c%20d"===e.href}catch(e){}}if(t||(t=document.baseURI||window.location.href),s)try{return new URL(e,t).href}catch(t){return e}return r||(r=document.implementation.createHTMLDocument("temp"),r.base=r.createElement("base"),r.head.appendChild(r.base),r.anchor=r.createElement("a"),r.body.appendChild(r.anchor)),r.base.href=t,r.anchor.href=e,r.anchor.href||e}function l(e,t){return e.replace(i,(function(e,n,s,r){return n+"'"+a(s.replace(/["']/g,""),t)+"'"+r}))}function d(e){return e.substring(0,e.lastIndexOf("/")+1)}},74460:(e,t,n)=>{n.d(t,{my:()=>r,FV:()=>i,sM:()=>o,v1:()=>a,f6:()=>l,XN:()=>d,ZN:()=>c,nL:()=>h,a2:()=>p,Hr:()=>u,HY:()=>_,ls:()=>f,z2:()=>m,gx:()=>y,ew:()=>g,dJ:()=>b,j8:()=>w,md:()=>P});n(56646);var s=n(42687);const r=!window.ShadyDOM||!window.ShadyDOM.inUse,i=(Boolean(!window.ShadyCSS||window.ShadyCSS.nativeCss),window.customElements.polyfillWrapFlushCallback,r&&"adoptedStyleSheets"in Document.prototype&&"replaceSync"in CSSStyleSheet.prototype&&(()=>{try{const e=new CSSStyleSheet;e.replaceSync("");const t=document.createElement("div");return t.attachShadow({mode:"open"}),t.shadowRoot.adoptedStyleSheets=[e],t.shadowRoot.adoptedStyleSheets[0]===e}catch(e){return!1}})());let o=window.Polymer&&window.Polymer.rootPath||(0,s.iY)(document.baseURI||window.location.href);let a=window.Polymer&&window.Polymer.sanitizeDOMValue||void 0;let l=window.Polymer&&window.Polymer.setPassiveTouchGestures||!1;let d=window.Polymer&&window.Polymer.strictTemplatePolicy||!1;let c=window.Polymer&&window.Polymer.allowTemplateFromDomModule||!1;let h=window.Polymer&&window.Polymer.legacyOptimizations||!1;let p=window.Polymer&&window.Polymer.legacyWarnings||!1;let u=window.Polymer&&window.Polymer.syncInitialRender||!1;let _=window.Polymer&&window.Polymer.legacyUndefined||!1;let f=window.Polymer&&window.Polymer.orderedComputed||!1;let m=!0;let y=window.Polymer&&window.Polymer.removeNestedTemplates||!1;let g=window.Polymer&&window.Polymer.fastDomIf||!1;let b=window.Polymer&&window.Polymer.suppressTemplateNotifications||!1;let w=window.Polymer&&window.Polymer.legacyNoObservedAttributes||!1;let P=window.Polymer&&window.Polymer.useAdoptedStyleSheetsWithBuiltCSS||!1},15392:(e,t,n)=>{n.d(t,{uT:()=>c,lx:()=>h,jv:()=>u});var s=n(21384),r=n(42687);const i="shady-unscoped";function o(e){return s.t.import(e)}function a(e){let t=e.body?e.body:e;const n=(0,r.Rq)(t.textContent,e.baseURI),s=document.createElement("style");return s.textContent=n,s}function l(e){const t=e.trim().split(/\s+/),n=[];for(let e=0;e<t.length;e++)n.push(...d(t[e]));return n}function d(e){const t=o(e);if(!t)return console.warn("Could not find style data in module named",e),[];if(void 0===t._styles){const e=[];e.push(...p(t));const n=t.querySelector("template");n&&e.push(...c(n,t.assetpath)),t._styles=e}return t._styles}function c(e,t){if(!e._styles){const n=[],s=e.content.querySelectorAll("style");for(let e=0;e<s.length;e++){let i=s[e],o=i.getAttribute("include");o&&n.push(...l(o).filter((function(e,t,n){return n.indexOf(e)===t}))),t&&(i.textContent=(0,r.Rq)(i.textContent,t)),n.push(i)}e._styles=n}return e._styles}function h(e){let t=o(e);return t?p(t):[]}function p(e){const t=[],n=e.querySelectorAll("link[rel=import][type~=css]");for(let e=0;e<n.length;e++){let s=n[e];if(s.import){const e=s.import,n=s.hasAttribute(i);if(n&&!e._unscopedStyle){const t=a(e);t.setAttribute(i,""),e._unscopedStyle=t}else e._style||(e._style=a(e));t.push(n?e._unscopedStyle:e._style)}}return t}function u(e){let t=e.trim().split(/\s+/),n="";for(let e=0;e<t.length;e++)n+=_(t[e]);return n}function _(e){let t=o(e);if(t&&void 0===t._cssText){let e=f(t),n=t.querySelector("template");n&&(e+=function(e,t){let n="";const s=c(e,t);for(let e=0;e<s.length;e++){let t=s[e];t.parentNode&&t.parentNode.removeChild(t),n+=t.textContent}return n}(n,t.assetpath)),t._cssText=e||null}return t||console.warn("Could not find style data in module named",e),t&&t._cssText||""}function f(e){let t="",n=p(e);for(let e=0;e<n.length;e++)t+=n[e].textContent;return t}},65412:(e,t,n)=>{n.d(t,{Gd:()=>s,z2:()=>i});function s(){0}const r=[];function i(e){r.push(e)}},52521:(e,t,n)=>{n.d(t,{aZ:()=>p,Uv:()=>w,GJ:()=>P});n(56646);var s=n(40729),r=n(18691),i=n(74460),o=n(62276);let a=null;function l(){return a}l.prototype=Object.create(HTMLTemplateElement.prototype,{constructor:{value:l,writable:!0}});const d=(0,s.q)(l),c=(0,r.E)(d);const h=(0,s.q)(class{});function p(e,t){for(let n=0;n<t.length;n++){let s=t[n];if(Boolean(e)!=Boolean(s.__hideTemplateChildren__))if(s.nodeType===Node.TEXT_NODE)e?(s.__polymerTextContent__=s.textContent,s.textContent=""):s.textContent=s.__polymerTextContent__;else if("slot"===s.localName)if(e)s.__polymerReplaced__=document.createComment("hidden-slot"),(0,o.r)((0,o.r)(s).parentNode).replaceChild(s.__polymerReplaced__,s);else{const e=s.__polymerReplaced__;e&&(0,o.r)((0,o.r)(e).parentNode).replaceChild(s,e)}else s.style&&(e?(s.__polymerDisplay__=s.style.display,s.style.display="none"):s.style.display=s.__polymerDisplay__);s.__hideTemplateChildren__=e,s._showHideChildren&&s._showHideChildren(e)}}class u extends h{constructor(e){super(),this._configureProperties(e),this.root=this._stampTemplate(this.__dataHost);let t=[];this.children=t;for(let e=this.root.firstChild;e;e=e.nextSibling)t.push(e),e.__templatizeInstance=this;this.__templatizeOwner&&this.__templatizeOwner.__hideTemplateChildren__&&this._showHideChildren(!0);let n=this.__templatizeOptions;(e&&n.instanceProps||!n.instanceProps)&&this._enableProperties()}_configureProperties(e){if(this.__templatizeOptions.forwardHostProp)for(let e in this.__hostProps)this._setPendingProperty(e,this.__dataHost["_host_"+e]);for(let t in e)this._setPendingProperty(t,e[t])}forwardHostProp(e,t){this._setPendingPropertyOrPath(e,t,!1,!0)&&this.__dataHost._enqueueClient(this)}_addEventListenerToNode(e,t,n){if(this._methodHost&&this.__templatizeOptions.parentModel)this._methodHost._addEventListenerToNode(e,t,(e=>{e.model=this,n(e)}));else{let s=this.__dataHost.__dataHost;s&&s._addEventListenerToNode(e,t,n)}}_showHideChildren(e){p(e,this.children)}_setUnmanagedPropertyToNode(e,t,n){e.__hideTemplateChildren__&&e.nodeType==Node.TEXT_NODE&&"textContent"==t?e.__polymerTextContent__=n:super._setUnmanagedPropertyToNode(e,t,n)}get parentModel(){let e=this.__parentModel;if(!e){let t;e=this;do{e=e.__dataHost.__dataHost}while((t=e.__templatizeOptions)&&!t.parentModel);this.__parentModel=e}return e}dispatchEvent(e){return!0}}u.prototype.__dataHost,u.prototype.__templatizeOptions,u.prototype._methodHost,u.prototype.__templatizeOwner,u.prototype.__hostProps;const _=(0,r.E)(u);function f(e){let t=e.__dataHost;return t&&t._methodHost||t}function m(e,t,n){let s=n.mutableData?_:u;w.mixin&&(s=w.mixin(s));let r=class extends s{};return r.prototype.__templatizeOptions=n,r.prototype._bindTemplate(e),function(e,t,n,s){let r=n.hostProps||{};for(let t in s.instanceProps){delete r[t];let n=s.notifyInstanceProp;n&&e.prototype._addPropertyEffect(t,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:b(t,n)})}if(s.forwardHostProp&&t.__dataHost)for(let t in r)n.hasHostProps||(n.hasHostProps=!0),e.prototype._addPropertyEffect(t,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:function(e,t,n){e.__dataHost._setPendingPropertyOrPath("_host_"+t,n[t],!0,!0)}})}(r,e,t,n),r}function y(e,t,n,s){let r=n.forwardHostProp;if(r&&t.hasHostProps){const h="template"==e.localName;let p=t.templatizeTemplateClass;if(!p){if(h){let e=n.mutableData?c:d;class s extends e{}p=t.templatizeTemplateClass=s}else{const n=e.constructor;class s extends n{}p=t.templatizeTemplateClass=s}let o=t.hostProps;for(let e in o)p.prototype._addPropertyEffect("_host_"+e,p.prototype.PROPERTY_EFFECT_TYPES.PROPAGATE,{fn:g(e,r)}),p.prototype._createNotifyingProperty("_host_"+e);i.a2&&s&&function(e,t,n){const s=n.constructor._properties,{propertyEffects:r}=e,{instanceProps:i}=t;for(let e in r)if(!(s[e]||i&&i[e])){const t=r[e];for(let n=0;n<t.length;n++){const{part:s}=t[n].info;if(!s.signature||!s.signature.static){console.warn(`Property '${e}' used in template but not declared in 'properties'; attribute will not be observed.`);break}}}}(t,n,s)}if(e.__dataProto&&Object.assign(e.__data,e.__dataProto),h)l=p,a=o=e,Object.setPrototypeOf(o,l.prototype),new l,a=null,e.__dataTemp={},e.__dataPending=null,e.__dataOld=null,e._enableProperties();else{Object.setPrototypeOf(e,p.prototype);const n=t.hostProps;for(let t in n)if(t="_host_"+t,t in e){const n=e[t];delete e[t],e.__data[t]=n}}}var o,l}function g(e,t){return function(e,n,s){t.call(e.__templatizeOwner,n.substring("_host_".length),s[n])}}function b(e,t){return function(e,n,s){t.call(e.__templatizeOwner,e,n,s[n])}}function w(e,t,n){if(i.XN&&!f(e))throw new Error("strictTemplatePolicy: template owner not trusted");if(n=n||{},e.__templatizeOwner)throw new Error("A <template> can only be templatized once");e.__templatizeOwner=t;let s=(t?t.constructor:u)._parseTemplate(e),r=s.templatizeInstanceClass;r||(r=m(e,s,n),s.templatizeInstanceClass=r);const o=f(e);y(e,s,n,o);let a=class extends r{};return a.prototype._methodHost=o,a.prototype.__dataHost=e,a.prototype.__templatizeOwner=t,a.prototype.__hostProps=s.hostProps,a=a,a}function P(e,t){let n;for(;t;)if(n=t.__dataHost?t:t.__templatizeInstance){if(n.__dataHost==e)return n;t=n.__dataHost}else t=(0,o.r)(t).parentNode;return null}},62276:(e,t,n)=>{n.d(t,{r:()=>s});const s=window.ShadyDOM&&window.ShadyDOM.noPatch&&window.ShadyDOM.wrap?window.ShadyDOM.wrap:window.ShadyDOM?e=>ShadyDOM.patch(e):e=>e},28426:(e,t,n)=>{n.d(t,{H3:()=>r});var s=n(36608);n(50856);const r=(0,s.SH)(HTMLElement)},94604:(e,t,n)=>{var s=n(18890),r=(n(9672),n(37692),n(56646),n(40729)),i=n(18691),o=n(60995),a=n(74460),l=n(62276),d=n(6226);const c=(0,o._)((0,i.w)((0,r.q)(HTMLElement)));customElements.define("dom-bind",class extends c{static get observedAttributes(){return["mutable-data"]}constructor(){if(super(),a.XN)throw new Error("strictTemplatePolicy: dom-bind not allowed");this.root=null,this.$=null,this.__children=null}attributeChangedCallback(e,t,n,s){this.mutableData=!0}connectedCallback(){(0,d.N)()||(this.style.display="none"),this.render()}disconnectedCallback(){this.__removeChildren()}__insertChildren(){(0,l.r)((0,l.r)(this).parentNode).insertBefore(this.root,this)}__removeChildren(){if(this.__children)for(let e=0;e<this.__children.length;e++)this.root.appendChild(this.__children[e])}render(){let e;if(!this.__children){if(e=e||this.querySelector("template"),!e){let t=new MutationObserver((()=>{if(e=this.querySelector("template"),!e)throw new Error("dom-bind requires a <template> child");t.disconnect(),this.render()}));return void t.observe(this,{childList:!0})}this.root=this._stampTemplate(e),this.$=this.root.$,this.__children=[];for(let e=this.root.firstChild;e;e=e.nextSibling)this.__children[this.__children.length]=e;this._enableProperties()}this.__insertChildren(),this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0}))}});n(42173);var h=n(28426),p=n(78956),u=n(93252),_=n(21683),f=n(4059),m=n(52521);class y extends h.H3{static get is(){return"dom-if"}static get template(){return null}static get properties(){return{if:{type:Boolean,observer:"__debounceRender"},restamp:{type:Boolean,observer:"__debounceRender"},notifyDomChange:{type:Boolean}}}constructor(){super(),this.__renderDebouncer=null,this._lastIf=!1,this.__hideTemplateChildren__=!1,this.__template,this._templateInfo}__debounceRender(){this.__renderDebouncer=p.dx.debounce(this.__renderDebouncer,_.YA,(()=>this.__render())),(0,u.E)(this.__renderDebouncer)}disconnectedCallback(){super.disconnectedCallback();const e=(0,l.r)(this).parentNode;e&&(e.nodeType!=Node.DOCUMENT_FRAGMENT_NODE||(0,l.r)(e).host)||this.__teardownInstance()}connectedCallback(){super.connectedCallback(),(0,d.N)()||(this.style.display="none"),this.if&&this.__debounceRender()}__ensureTemplate(){if(!this.__template){const e=this;let t=e._templateInfo?e:(0,l.r)(e).querySelector("template");if(!t){let e=new MutationObserver((()=>{if(!(0,l.r)(this).querySelector("template"))throw new Error("dom-if requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}this.__template=t}return!0}__ensureInstance(){let e=(0,l.r)(this).parentNode;if(this.__hasInstance()){let t=this.__getInstanceNodes();if(t&&t.length){if((0,l.r)(this).previousSibling!==t[t.length-1])for(let n,s=0;s<t.length&&(n=t[s]);s++)(0,l.r)(e).insertBefore(n,this)}}else{if(!e)return!1;if(!this.__ensureTemplate())return!1;this.__createAndInsertInstance(e)}return!0}render(){(0,u.y)()}__render(){if(this.if){if(!this.__ensureInstance())return}else this.restamp&&this.__teardownInstance();this._showHideChildren(),a.dJ&&!this.notifyDomChange||this.if==this._lastIf||(this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0})),this._lastIf=this.if)}__hasInstance(){}__getInstanceNodes(){}__createAndInsertInstance(e){}__teardownInstance(){}_showHideChildren(){}}const g=a.ew?class extends y{constructor(){super(),this.__instance=null,this.__syncInfo=null}__hasInstance(){return Boolean(this.__instance)}__getInstanceNodes(){return this.__instance.templateInfo.childNodes}__createAndInsertInstance(e){const t=this.__dataHost||this;if(a.XN&&!this.__dataHost)throw new Error("strictTemplatePolicy: template owner not trusted");const n=t._bindTemplate(this.__template,!0);n.runEffects=(e,t,n)=>{let s=this.__syncInfo;if(this.if)s&&(this.__syncInfo=null,this._showHideChildren(),t=Object.assign(s.changedProps,t)),e(t,n);else if(this.__instance)if(s||(s=this.__syncInfo={runEffects:e,changedProps:{}}),n)for(const e in t){const t=(0,f.Jz)(e);s.changedProps[t]=this.__dataHost[t]}else Object.assign(s.changedProps,t)},this.__instance=t._stampTemplate(this.__template,n),(0,l.r)(e).insertBefore(this.__instance,this)}__syncHostProperties(){const e=this.__syncInfo;e&&(this.__syncInfo=null,e.runEffects(e.changedProps,!1))}__teardownInstance(){const e=this.__dataHost||this;this.__instance&&(e._removeBoundDom(this.__instance),this.__instance=null,this.__syncInfo=null)}_showHideChildren(){const e=this.__hideTemplateChildren__||!this.if;this.__instance&&Boolean(this.__instance.__hidden)!==e&&(this.__instance.__hidden=e,(0,m.aZ)(e,this.__instance.templateInfo.childNodes)),e||this.__syncHostProperties()}}:class extends y{constructor(){super(),this.__ctor=null,this.__instance=null,this.__invalidProps=null}__hasInstance(){return Boolean(this.__instance)}__getInstanceNodes(){return this.__instance.children}__createAndInsertInstance(e){this.__ctor||(this.__ctor=(0,m.Uv)(this.__template,this,{mutableData:!0,forwardHostProp:function(e,t){this.__instance&&(this.if?this.__instance.forwardHostProp(e,t):(this.__invalidProps=this.__invalidProps||Object.create(null),this.__invalidProps[(0,f.Jz)(e)]=!0))}})),this.__instance=new this.__ctor,(0,l.r)(e).insertBefore(this.__instance.root,this)}__teardownInstance(){if(this.__instance){let e=this.__instance.children;if(e&&e.length){let t=(0,l.r)(e[0]).parentNode;if(t){t=(0,l.r)(t);for(let n,s=0;s<e.length&&(n=e[s]);s++)t.removeChild(n)}}this.__invalidProps=null,this.__instance=null}}__syncHostProperties(){let e=this.__invalidProps;if(e){this.__invalidProps=null;for(let t in e)this.__instance._setPendingProperty(t,this.__dataHost[t]);this.__instance._flushProperties()}}_showHideChildren(){const e=this.__hideTemplateChildren__||!this.if;this.__instance&&Boolean(this.__instance.__hidden)!==e&&(this.__instance.__hidden=e,this.__instance._showHideChildren(e)),e||this.__syncHostProperties()}};customElements.define(g.is,g);var b=n(76389),w=n(4507),P=n(36608);let C=(0,b.o)((e=>{let t=(0,P.SH)(e);return class extends t{static get properties(){return{items:{type:Array},multi:{type:Boolean,value:!1},selected:{type:Object,notify:!0},selectedItem:{type:Object,notify:!0},toggle:{type:Boolean,value:!1}}}static get observers(){return["__updateSelection(multi, items.*)"]}constructor(){super(),this.__lastItems=null,this.__lastMulti=null,this.__selectedMap=null}__updateSelection(e,t){let n=t.path;if(n==JSCompiler_renameProperty("items",this)){let n=t.base||[],s=this.__lastItems;if(e!==this.__lastMulti&&this.clearSelection(),s){let e=(0,w.c)(n,s);this.__applySplices(e)}this.__lastItems=n,this.__lastMulti=e}else if(t.path==`${JSCompiler_renameProperty("items",this)}.splices`)this.__applySplices(t.value.indexSplices);else{let e=n.slice(`${JSCompiler_renameProperty("items",this)}.`.length),t=parseInt(e,10);e.indexOf(".")<0&&e==t&&this.__deselectChangedIdx(t)}}__applySplices(e){let t=this.__selectedMap;for(let n=0;n<e.length;n++){let s=e[n];t.forEach(((e,n)=>{e<s.index||(e>=s.index+s.removed.length?t.set(n,e+s.addedCount-s.removed.length):t.set(n,-1))}));for(let e=0;e<s.addedCount;e++){let n=s.index+e;t.has(this.items[n])&&t.set(this.items[n],n)}}this.__updateLinks();let n=0;t.forEach(((e,s)=>{e<0?(this.multi?this.splice(JSCompiler_renameProperty("selected",this),n,1):this.selected=this.selectedItem=null,t.delete(s)):n++}))}__updateLinks(){if(this.__dataLinkedPaths={},this.multi){let e=0;this.__selectedMap.forEach((t=>{t>=0&&this.linkPaths(`${JSCompiler_renameProperty("items",this)}.${t}`,`${JSCompiler_renameProperty("selected",this)}.${e++}`)}))}else this.__selectedMap.forEach((e=>{this.linkPaths(JSCompiler_renameProperty("selected",this),`${JSCompiler_renameProperty("items",this)}.${e}`),this.linkPaths(JSCompiler_renameProperty("selectedItem",this),`${JSCompiler_renameProperty("items",this)}.${e}`)}))}clearSelection(){this.__dataLinkedPaths={},this.__selectedMap=new Map,this.selected=this.multi?[]:null,this.selectedItem=null}isSelected(e){return this.__selectedMap.has(e)}isIndexSelected(e){return this.isSelected(this.items[e])}__deselectChangedIdx(e){let t=this.__selectedIndexForItemIndex(e);if(t>=0){let e=0;this.__selectedMap.forEach(((n,s)=>{t==e++&&this.deselect(s)}))}}__selectedIndexForItemIndex(e){let t=this.__dataLinkedPaths[`${JSCompiler_renameProperty("items",this)}.${e}`];if(t)return parseInt(t.slice(`${JSCompiler_renameProperty("selected",this)}.`.length),10)}deselect(e){let t=this.__selectedMap.get(e);if(t>=0){let n;this.__selectedMap.delete(e),this.multi&&(n=this.__selectedIndexForItemIndex(t)),this.__updateLinks(),this.multi?this.splice(JSCompiler_renameProperty("selected",this),n,1):this.selected=this.selectedItem=null}}deselectIndex(e){this.deselect(this.items[e])}select(e){this.selectIndex(this.items.indexOf(e))}selectIndex(e){let t=this.items[e];this.isSelected(t)?this.toggle&&this.deselectIndex(e):(this.multi||this.__selectedMap.clear(),this.__selectedMap.set(t,e),this.__updateLinks(),this.multi?this.push(JSCompiler_renameProperty("selected",this),t):this.selected=this.selectedItem=t)}}})),v=C(h.H3);class x extends v{static get is(){return"array-selector"}static get template(){return null}}customElements.define(x.is,x);n(5618),n(72419),n(50856);(0,s.x)(HTMLElement).prototype},60309:(e,t,n)=>{n.d(t,{CN:()=>s,$T:()=>r,mA:()=>i});const s=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,r=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,i=/@media\s(.*)/},10868:(e,t,n)=>{n.d(t,{wW:()=>r,B7:()=>i,OH:()=>o});var s=n(60309);function r(e,t){for(let n in t)null===n?e.style.removeProperty(n):e.style.setProperty(n,t[n])}function i(e,t){const n=window.getComputedStyle(e).getPropertyValue(t);return n?n.trim():""}function o(e){const t=s.$T.test(e)||s.CN.test(e);return s.$T.lastIndex=0,s.CN.lastIndex=0,t}},34816:(e,t,n)=>{n.d(t,{ZP:()=>h});let s,r=null,i=window.HTMLImports&&window.HTMLImports.whenReady||null;function o(e){requestAnimationFrame((function(){i?i(e):(r||(r=new Promise((e=>{s=e})),"complete"===document.readyState?s():document.addEventListener("readystatechange",(()=>{"complete"===document.readyState&&s()}))),r.then((function(){e&&e()})))}))}const a="__seenByShadyCSS",l="__shadyCSSCachedStyle";let d=null,c=null;class h{constructor(){this.customStyles=[],this.enqueued=!1,o((()=>{window.ShadyCSS.flushCustomStyles&&window.ShadyCSS.flushCustomStyles()}))}enqueueDocumentValidation(){!this.enqueued&&c&&(this.enqueued=!0,o(c))}addCustomStyle(e){e[a]||(e[a]=!0,this.customStyles.push(e),this.enqueueDocumentValidation())}getStyleForCustomStyle(e){if(e[l])return e[l];let t;return t=e.getStyle?e.getStyle():e,t}processStyles(){const e=this.customStyles;for(let t=0;t<e.length;t++){const n=e[t];if(n[l])continue;const s=this.getStyleForCustomStyle(n);if(s){const e=s.__appliedElement||s;d&&d(e),n[l]=e}}return e}}h.prototype.addCustomStyle=h.prototype.addCustomStyle,h.prototype.getStyleForCustomStyle=h.prototype.getStyleForCustomStyle,h.prototype.processStyles=h.prototype.processStyles,Object.defineProperties(h.prototype,{transformCallback:{get:()=>d,set(e){d=e}},validateCallback:{get:()=>c,set(e){let t=!1;c||(t=!0),c=e,t&&this.enqueueDocumentValidation()}}})},26539:(e,t,n)=>{n.d(t,{WA:()=>s,Cp:()=>i,jF:()=>a,rd:()=>l});const s=!(window.ShadyDOM&&window.ShadyDOM.inUse);let r,i;function o(e){r=(!e||!e.shimcssproperties)&&(s||Boolean(!navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)&&window.CSS&&CSS.supports&&CSS.supports("box-shadow","0 0 0 var(--foo)")))}window.ShadyCSS&&void 0!==window.ShadyCSS.cssBuild&&(i=window.ShadyCSS.cssBuild);const a=Boolean(window.ShadyCSS&&window.ShadyCSS.disableRuntime);window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?r=window.ShadyCSS.nativeCss:window.ShadyCSS?(o(window.ShadyCSS),window.ShadyCSS=void 0):o(window.WebComponents&&window.WebComponents.flags);const l=r}}]);
//# sourceMappingURL=7107eafb.js.map